@@ -14,7 +14,7 @@ import (
 
 	"github.com/xyproto/files"
 	"github.com/xyproto/mode"
-	"github.com/xyproto/vt100"
+	"github.com/xyproto/vt"
 )
 
 var (
@@ -83,10 +83,14 @@ func (e *Editor) exeName(sourceFilename string, shouldExist bool) string {
 	return exeFirstName
 }
 
+func has(executableInPath string) bool {
+	return files.WhichCached(executableInPath) != ""
+}
+
 // GenerateBuildCommand will generate a command for building the given filename (or for displaying HTML)
 // If there are no errors, a exec.Cmd is returned together with a function that can tell if the build
 // produced an executable, together with the executable name,
-func (e *Editor) GenerateBuildCommand(c *vt100.Canvas, tty *vt100.TTY, filename string) (*exec.Cmd, func() (bool, string), error) {
+func (e *Editor) GenerateBuildCommand(c *vt.Canvas, tty *vt.TTY, filename string) (*exec.Cmd, func() (bool, string), error) {
 	var cmd *exec.Cmd
 
 	// A function that signals that everything is fine, regardless of if an executable is produced or not, after building
@@ -138,28 +142,51 @@ func (e *Editor) GenerateBuildCommand(c *vt100.Canvas, tty *vt100.TTY, filename
 		return files.IsFile(filepath.Join(sourceDir, "main")), "main"
 	}
 
-	exeBaseNameOrMainExists := func() (bool, string) {
-		// First check if exeFirstName exists
-		if files.IsFile(filepath.Join(sourceDir, exeFirstName)) {
-			return true, exeFirstName
-		}
-		// Then try with the current directory name
-		baseDirName := filepath.Base(sourceDir)
-		if files.IsFile(filepath.Join(sourceDir, baseDirName)) {
-			return true, baseDirName
-		}
-		// The try with just "main"
-		if files.IsFile(filepath.Join(sourceDir, "main")) {
-			return true, "main"
-		}
-		return false, ""
-	}
-
 	switch filepath.Base(sourceFilename) {
-	case "PKGBUILD":
-		has := func(s string) bool {
-			return files.WhichCached(s) != ""
+	case "CMakeLists.txt":
+		var s string
+		if has("cmake") {
+			s = "cmake -B build -D CMAKE_BUILD_TYPE=Debug -G Ninja -S . -W no-dev || (rm -rv build; cmake -B build -D CMAKE_BUILD_TYPE=Debug -G Ninja -S . -W no-dev) && ninja -C build"
+			if !has("ninja") {
+				s = strings.ReplaceAll(s, " -G Ninja", "")
+				s = strings.ReplaceAll(s, "ninja -C ", "make -C ")
+			}
+			if isBSD && has("gmake") {
+				s = strings.ReplaceAll(s, "make -C ", "gmake -C ")
+			}
 		}
+		lastCommand, err := readLastCommand()
+		if releaseBuildFlag {
+			if err == nil && strings.Contains(lastCommand, "CMAKE_BUILD_TYPE=Debug ") {
+				s = "rm -r build; " + s
+			}
+			s = strings.ReplaceAll(s, "CMAKE_BUILD_TYPE=Debug ", "CMAKE_BUILD_TYPE=Release ")
+		} else {
+			if err == nil && strings.Contains(lastCommand, "CMAKE_BUILD_TYPE=Release ") {
+				s = "rm -r build; " + s
+			}
+		}
+		if s != "" {
+			// Save and exec / replace the process with syscall.Exec
+			if e.Save(c, tty) == nil { // success
+				// Unlock and save the lock file
+				if absFilename, err := filepath.Abs(e.filename); fileLock != nil && err == nil { // success
+					go func() {
+						quitMut.Lock()
+						defer quitMut.Unlock()
+						fileLock.Unlock(absFilename)
+						fileLock.Save()
+					}()
+				}
+				quitExecShellCommand(tty, sourceDir, s) // The program ends here
+			}
+			// Could not save the file, execute the command in a separate process
+			args := strings.Split(s, " ")
+			cmd = exec.Command(args[0], args[1:]...)
+			cmd.Dir = sourceDir
+			return cmd, everythingIsFine, nil
+		}
+	case "PKGBUILD":
 		var s string
 		if has("tinyionice") {
 			s += "tinyionice "
@@ -179,12 +206,15 @@ func (e *Editor) GenerateBuildCommand(c *vt100.Canvas, tty *vt100.TTY, filename
 			if e.Save(c, tty) == nil { // success
 				// Unlock and save the lock file
 				if absFilename, err := filepath.Abs(e.filename); fileLock != nil && err == nil { // success
-					fileLock.Unlock(absFilename)
-					fileLock.Save()
+					go func() {
+						quitMut.Lock()
+						defer quitMut.Unlock()
+						fileLock.Unlock(absFilename)
+						fileLock.Save()
+					}()
 				}
 				quitExecShellCommand(tty, sourceDir, s) // The program ends here
 			}
-
 			// Could not save the file, execute the command in a separate process
 			args := strings.Split(s, " ")
 			cmd = exec.Command(args[0], args[1:]...)
@@ -194,17 +224,43 @@ func (e *Editor) GenerateBuildCommand(c *vt100.Canvas, tty *vt100.TTY, filename
 	}
 
 	switch e.mode {
+	case mode.ABC:
+		cmd = exec.Command("abc2midi", e.filename, "-o", filepath.Join(tempDir, "o.mid"))
+		cmd.Dir = sourceDir
+		return cmd, everythingIsFine, nil
+	case mode.Chuck, mode.SuperCollider:
+		cmd = exec.Command("true")
+		cmd.Dir = sourceDir
+		return cmd, everythingIsFine, nil
 	case mode.Make:
 		cmd = exec.Command("make")
 		cmd.Dir = sourceDir
 		return cmd, everythingIsFine, nil
 	case mode.Java: // build a .jar file
-		javaShellCommand := "javaFiles=$(find . -type f -name '*.java'); for f in $javaFiles; do grep -q 'static void main' \"$f\" && mainJavaFile=\"$f\"; done; className=$(grep -oP '(?<=class )[A-Z]+[a-z,A-Z,0-9]*' \"$mainJavaFile\" | head -1); packageName=$(grep -oP '(?<=package )[a-z,A-Z,0-9,.]*' \"$mainJavaFile\" | head -1); if [[ $packageName != \"\" ]]; then packageName=\"$packageName.\"; fi; mkdir -p _o_build/META-INF; javac -d _o_build $javaFiles; cd _o_build; echo \"Main-Class: $packageName$className\" > META-INF/MANIFEST.MF; classFiles=$(find . -type f -name '*.class'); jar cmf META-INF/MANIFEST.MF ../" + jarFilename + " $classFiles; cd ..; rm -rf _o_build"
+		javaShellCommand := "javaFiles=$(find . -type f -name '*.java'); " +
+			"for f in $javaFiles; do grep -q 'static void main' \"$f\" && mainJavaFile=\"$f\"; done; " +
+			"if command -v grep >/dev/null 2>&1 && echo 'test' | grep -P 'test' >/dev/null 2>&1; then " +
+			"className=$(grep -oP '(?<=class )[A-Z][a-zA-Z0-9]*' \"$mainJavaFile\" | head -1); " +
+			"packageName=$(grep -oP '(?<=package )[a-zA-Z0-9.]*' \"$mainJavaFile\" | head -1); " +
+			"else " +
+			"className=$(grep -E 'class [A-Z][a-zA-Z0-9]*' \"$mainJavaFile\" | sed -E 's/.*class ([A-Z][a-zA-Z0-9]*).*/\\1/' | head -1); " +
+			"packageName=$(grep -E 'package [a-zA-Z0-9.]*' \"$mainJavaFile\" | sed -E 's/.*package ([a-zA-Z0-9.]*).*/\\1/' | head -1); " +
+			"fi; " +
+			"if [[ $packageName != \"\" ]]; then packageName=\"$packageName.\"; fi; " +
+			"mkdir -p _o_build/META-INF; " +
+			"javac -d _o_build $javaFiles; " +
+			"cd _o_build; " +
+			"echo \"Main-Class: $packageName$className\" > META-INF/MANIFEST.MF; " +
+			"classFiles=$(find . -type f -name '*.class'); " +
+			"jar cmf META-INF/MANIFEST.MF ../" + jarFilename + " $classFiles; " +
+			"cd ..; " +
+			"rm -rf _o_build"
 		cmd = exec.Command("sh", "-c", javaShellCommand)
 		cmd.Dir = sourceDir
 		return cmd, func() (bool, string) {
 			return files.IsFile(filepath.Join(sourceDir, jarFilename)), jarFilename
 		}, nil
+
 	case mode.Scala:
 		if files.IsFile(filepath.Join(sourceDir, "build.sbt")) && files.WhichCached("sbt") != "" && files.FileHas(filepath.Join(sourceDir, "build.sbt"), "ScalaNative") {
 			cmd = exec.Command("sbt", "nativeLink")
@@ -286,14 +342,6 @@ func (e *Editor) GenerateBuildCommand(c *vt100.Canvas, tty *vt100.TTY, filename
 			return files.IsFile(sourceFilenameWithoutPath), executableFirstName
 		}, nil
 	case mode.C:
-		if files.WhichCached("cxx") != "" {
-			cmd = exec.Command("cxx")
-			cmd.Dir = sourceDir
-			if e.debugMode {
-				cmd.Args = append(cmd.Args, "debugnosan")
-			}
-			return cmd, exeBaseNameOrMainExists, nil
-		}
 		if files.IsDir(exeFilename) {
 			exeFilename = "main"
 		}
@@ -310,14 +358,6 @@ func (e *Editor) GenerateBuildCommand(c *vt100.Canvas, tty *vt100.TTY, filename
 		if files.IsFile("BUILD.bazel") && files.WhichCached("bazel") != "" { // Google-style C++ + Bazel projects if
 			return exec.Command("bazel", "build"), everythingIsFine, nil
 		}
-		if files.WhichCached("cxx") != "" {
-			cmd = exec.Command("cxx")
-			cmd.Dir = sourceDir
-			if e.debugMode {
-				cmd.Args = append(cmd.Args, "debugnosan")
-			}
-			return cmd, exeBaseNameOrMainExists, nil
-		}
 		if files.IsDir(exeFilename) {
 			exeFilename = "main"
 		}
@@ -410,12 +450,18 @@ func (e *Editor) GenerateBuildCommand(c *vt100.Canvas, tty *vt100.TTY, filename
 			cmd.Dir = parentDir
 		} else if !projectFileExists && !parentProjectFileExists && grandParentProjectFileExists {
 			cmd.Dir = grandParentDir
+		} else if !projectFileExists && !parentProjectFileExists && !grandParentProjectFileExists {
+			cmd = exec.Command("clojure", "-e", `(try (clojure.core/read-string (slurp "`+sourceFilename+`")) (println "Syntax OK") (catch Exception e (println "Syntax error:" (.getMessage e))))`)
+			cmd.Dir = sourceDir
 		}
 		return cmd, everythingIsFine, nil
 	case mode.Haskell:
 		cmd = exec.Command("ghc", "-dynamic", sourceFilename)
 		cmd.Dir = sourceDir
 		return cmd, everythingIsFine, nil
+	case mode.Perl:
+		cmd = exec.Command("perl", "-c", sourceFilename)
+		return cmd, everythingIsFine, nil
 	case mode.Python:
 		if isDarwin {
 			cmd = exec.Command("python3", "-m", "py_compile", sourceFilename)
@@ -437,6 +483,10 @@ func (e *Editor) GenerateBuildCommand(c *vt100.Canvas, tty *vt100.TTY, filename
 		cmd = exec.Command("crystal", "build", "--no-color", sourceFilename)
 		cmd.Dir = sourceDir
 		return cmd, everythingIsFine, nil
+	case mode.COBOL:
+		cmd = exec.Command("cobc", "-x", "-o", exeFirstName, sourceFilename)
+		cmd.Dir = sourceDir
+		return cmd, everythingIsFine, nil
 	case mode.Dart:
 		cmd = exec.Command("dart", "compile", "exe", "--verbosity", "error", "-o", exeFirstName, sourceFilename)
 		cmd.Dir = sourceDir
@@ -501,6 +551,10 @@ func (e *Editor) GenerateBuildCommand(c *vt100.Canvas, tty *vt100.TTY, filename
 		cmd = exec.Command("mlton", sourceFilename)
 		cmd.Dir = sourceDir
 		return cmd, everythingIsFine, nil
+	case mode.C67:
+		cmd = exec.Command("c67", "-o", exeFilename, sourceFilename)
+		cmd.Dir = sourceDir
+		return cmd, everythingIsFine, nil
 	case mode.Agda:
 		cmd = exec.Command("agda", "-c", sourceFilename)
 		cmd.Dir = sourceDir
@@ -537,10 +591,7 @@ func (e *Editor) GenerateBuildCommand(c *vt100.Canvas, tty *vt100.TTY, filename
 // BuildOrExport will try to build the source code or export the document.
 // Returns a status message and then true if an action was performed and another true if compilation/testing worked out.
 // Will also return the executable output file, if available after compilation.
-func (e *Editor) BuildOrExport(tty *vt100.TTY, c *vt100.Canvas, status *StatusBar) (string, error) {
-	// Build or export in the background
-	background := e.mode == mode.Markdown
-
+func (e *Editor) BuildOrExport(tty *vt.TTY, c *vt.Canvas, status *StatusBar) (string, error) {
 	// Clear the status messages, if we have a status bar
 	if status != nil && c != nil {
 		status.ClearAll(c, false)
@@ -578,7 +629,7 @@ func (e *Editor) BuildOrExport(tty *vt100.TTY, c *vt100.Canvas, status *StatusBa
 		const manFilename = "out.1"
 		status.SetMessage("Exporting ASCIIDoc to PDF")
 		status.Show(c, e)
-		if err := e.exportAdoc(c, tty, manFilename); err != nil {
+		if err := e.exportAdoc(manFilename); err != nil {
 			return "", err
 		}
 		if status != nil {
@@ -596,17 +647,14 @@ func (e *Editor) BuildOrExport(tty *vt100.TTY, c *vt100.Canvas, status *StatusBa
 		return outputFilename, cmd.Run()
 	case mode.Markdown:
 		htmlFilename := strings.ReplaceAll(filepath.Base(sourceFilename), ".", "_") + ".html"
-		if background {
-			go func() {
-				_ = e.exportMarkdownHTML(c, status, htmlFilename)
-			}()
-		} else {
-			if err := e.exportMarkdownHTML(c, status, htmlFilename); err != nil {
-				return htmlFilename, err
-			}
-		}
-		// the exportPandoc function handles it's own status output
+		go func() {
+			_ = e.exportMarkdownHTML(c, status, htmlFilename)
+		}()
 		return htmlFilename, nil
+	case mode.Lua:
+		if e.LuaLoveOrLovr() {
+			return "", nil
+		}
 	}
 
 	// The immediate builds are done, time to build a exec.Cmd, run it and analyze the output
@@ -662,7 +710,7 @@ func (e *Editor) BuildOrExport(tty *vt100.TTY, c *vt100.Canvas, status *StatusBa
 	}
 
 	// Check if there was a non-zero exit code together with no output
-	if exitCode != 0 && len(outputString) == 0 {
+	if exitCode != 0 && outputString == "" {
 		return "", errors.New("non-zero exit code and no error message")
 	}
 
@@ -1156,11 +1204,11 @@ func (e *Editor) BuildOrExport(tty *vt100.TTY, c *vt100.Canvas, status *StatusBa
 }
 
 // Build starts a build and is typically triggered from either ctrl-space or the o menu
-func (e *Editor) Build(c *vt100.Canvas, status *StatusBar, tty *vt100.TTY, alsoRun, markdownDoubleSpacePrevention bool) {
-	// Enable only. e.runAfterBuild is set to false elsewhere.
-	if alsoRun {
-		e.runAfterBuild = true
-	}
+func (e *Editor) Build(c *vt.Canvas, status *StatusBar, tty *vt.TTY) {
+	notRegularEditingRightNow.Store(true)
+	defer func() {
+		notRegularEditingRightNow.Store(false)
+	}()
 
 	// If the file is empty, there is nothing to build
 	if e.Empty() {
@@ -1234,7 +1282,7 @@ func (e *Editor) Build(c *vt100.Canvas, status *StatusBar, tty *vt100.TTY, alsoR
 	e.redraw.Store(false)
 
 	// Require a double ctrl-space when exporting Markdown to HTML, because it is so easy to press by accident
-	if markdownDoubleSpacePrevention && (e.mode == mode.Markdown && !alsoRun) {
+	if e.mode == mode.Markdown && !e.runAfterBuild {
 		return
 	}
 
@@ -1243,7 +1291,8 @@ func (e *Editor) Build(c *vt100.Canvas, status *StatusBar, tty *vt100.TTY, alsoR
 		if e.CanRun() {
 			status.ClearAll(c, false)
 			const repositionCursorAfterDrawing = true
-			e.DrawOutput(c, 20, "", "Building and running...", e.DebugRegistersBackground, repositionCursorAfterDrawing)
+			const rightHandSide = true
+			e.DrawOutput(c, 20, "", "Building and running...", e.DebugRegistersBackground, repositionCursorAfterDrawing, rightHandSide)
 			e.runAfterBuild = true
 		}
 		return
@@ -1263,10 +1312,32 @@ func (e *Editor) Build(c *vt100.Canvas, status *StatusBar, tty *vt100.TTY, alsoR
 
 				doneRunning := false
 				go func() {
+					// TODO: Wait for the process to start instead of sleeping
 					time.Sleep(500 * time.Millisecond)
 					if !doneRunning {
 						const repositionCursorAfterDrawing = true
-						e.DrawOutput(c, 20, "", "Done building. Running...", e.DebugStoppedBackground, repositionCursorAfterDrawing)
+						const rightHandSide = true
+						if skipTheStatusBox := e.mode == mode.Lua && e.LuaLoveOrLovr(); !skipTheStatusBox {
+							msg := "Done building. Running..."
+							switch e.mode {
+							case mode.ABC, mode.Chuck, mode.SuperCollider:
+								msg = fmt.Sprintf("Playing with %s...", e.mode)
+							case mode.JavaScript, mode.Lua, mode.Python, mode.Shell, mode.TypeScript:
+								if e.flaskApplication.Load() {
+									msg = "Serving Flask on http://127.0.0.1:5000/ ..."
+									var cmd *exec.Cmd
+									if isDarwin {
+										cmd = exec.Command("open", "http://127.0.0.1:5000")
+									} else {
+										cmd = exec.Command("xdg-open", "http://127.0.0.1:5000")
+									}
+									cmd.Run()
+								} else {
+									msg = "Running..."
+								}
+							}
+							e.DrawOutput(c, 20, "", "  "+msg, e.DebugStoppedBackground, repositionCursorAfterDrawing, rightHandSide)
+						}
 					}
 				}()
 
@@ -1277,6 +1348,12 @@ func (e *Editor) Build(c *vt100.Canvas, status *StatusBar, tty *vt100.TTY, alsoR
 					status.Show(c, e)
 					return // from goroutine
 				}
+
+				// Clear the "Done building. Running..." box
+				const drawLines = true
+				const shouldHighlightCurrentLine = false
+				e.FullResetRedraw(c, status, drawLines, shouldHighlightCurrentLine)
+
 				title := "Program output"
 				n := 25
 				h := float64(c.Height())
@@ -1291,7 +1368,6 @@ func (e *Editor) Build(c *vt100.Canvas, status *StatusBar, tty *vt100.TTY, alsoR
 				if strings.Count(output, "\n") >= n {
 					title = fmt.Sprintf("Last %d lines of output", n)
 				}
-				const repositionCursorAfterDrawing = true
 				boxBackgroundColor := e.DebugRunningBackground
 				if useErrorStyle {
 					boxBackgroundColor = e.DebugStoppedBackground
@@ -1300,7 +1376,11 @@ func (e *Editor) Build(c *vt100.Canvas, status *StatusBar, tty *vt100.TTY, alsoR
 					status.SetMessage("Success")
 				}
 				if strings.TrimSpace(output) != "" {
-					e.DrawOutput(c, n, title, output, boxBackgroundColor, repositionCursorAfterDrawing)
+					const rightHandSide = false
+					const repositionCursorAfterDrawing = true
+					e.DrawOutput(c, n, title, output, boxBackgroundColor, repositionCursorAfterDrawing, rightHandSide)
+				} else {
+					e.FullResetRedraw(c, status, true, false)
 				}
 				// Regular success, no debug mode
 				status.Show(c, e)
@@ -1346,7 +1426,7 @@ func (e *Editor) Build(c *vt100.Canvas, status *StatusBar, tty *vt100.TTY, alsoR
 // OnlyBuild tries to build/export the given FilenameOrData, without starting a full editor
 func OnlyBuild(fnord FilenameOrData) (string, error) {
 	// Prepare an editor, without tty and canvas
-	e, _, _, err := NewEditor(nil, nil, fnord, 0, 0, NewDefaultTheme(), false, true, false, false, false, false)
+	e, _, _, err := NewEditor(nil, nil, fnord, 0, 0, NewDefaultTheme(), false, true, false, false, false, false, false)
 	if err != nil {
 		return "", err
 	}
