@@ -10,7 +10,7 @@ import (
 	"github.com/xyproto/env/v2"
 	"github.com/xyproto/files"
 	"github.com/xyproto/mode"
-	"github.com/xyproto/vt100"
+	"github.com/xyproto/vt"
 )
 
 var (
@@ -35,7 +35,7 @@ func NewActions() *Actions {
 }
 
 // UserSave saves the file and the location history
-func (e *Editor) UserSave(c *vt100.Canvas, tty *vt100.TTY, status *StatusBar) {
+func (e *Editor) UserSave(c *vt.Canvas, tty *vt.TTY, status *StatusBar) {
 	// Save the file
 	if err := e.Save(c, tty); err != nil {
 		if msg := err.Error(); strings.HasPrefix(msg, "open ") && strings.Contains(msg, ": ") {
@@ -83,7 +83,7 @@ func (a *Actions) Perform(index int) {
 }
 
 // AddCommand will add a command to the action menu, if it can be looked up by e.CommandToFunction
-func (a *Actions) AddCommand(e *Editor, c *vt100.Canvas, tty *vt100.TTY, status *StatusBar, bookmark *Position, undo *Undo, title string, args ...string) error {
+func (a *Actions) AddCommand(e *Editor, c *vt.Canvas, tty *vt.TTY, status *StatusBar, bookmark *Position, undo *Undo, title string, args ...string) error {
 	f, err := e.CommandToFunction(c, tty, status, bookmark, undo, args...)
 	if err != nil {
 		return err
@@ -95,13 +95,20 @@ func (a *Actions) AddCommand(e *Editor, c *vt100.Canvas, tty *vt100.TTY, status
 // CommandMenu will display a menu with various commands that can be browsed with arrow up and arrow down.
 // Also returns the selected menu index (can be -1), and if a space should be added to the text editor after the return.
 // Returns -1, true if space was pressed.
-func (e *Editor) CommandMenu(c *vt100.Canvas, tty *vt100.TTY, status *StatusBar, bookmark *Position, undo *Undo, lastMenuIndex int, forced bool, lk *LockKeeper) (int, bool) {
+func (e *Editor) CommandMenu(c *vt.Canvas, tty *vt.TTY, status *StatusBar, bookmark *Position, undo *Undo, lastMenuIndex int, forced bool, fileLock *LockKeeper) (int, bool) {
 	const insertFilename = "include.txt"
 
-	if menuTitle == "" {
+	notRegularEditingRightNow.Store(true)
+	defer func() {
+		notRegularEditingRightNow.Store(false)
+	}()
+
+	vsCode := env.Str("TERM_PROGRAM") == "vscode"
+
+	if (menuTitle == "" || len(backFunctions) == 0) && !strings.HasPrefix(menuTitle, "Editing ") {
 		menuTitle = versionString
-	} else if menuTitle == versionString {
-		menuTitle = "Menu"
+	} else {
+		menuTitle = "Editing " + filepath.Base(e.filename)
 	}
 
 	wrapWidth := e.wrapWidth
@@ -129,39 +136,40 @@ func (e *Editor) CommandMenu(c *vt100.Canvas, tty *vt100.TTY, status *StatusBar,
 	actions.AddCommand(e, c, tty, status, bookmark, undo, "Sort the current block of lines", "sortblock")
 	actions.AddCommand(e, c, tty, status, bookmark, undo, "Sort strings on the current line", "sortwords")
 
-	actions.AddCommand(e, c, tty, status, bookmark, undo, "Insert \""+insertFilename+"\" at the current line", "insertfile", insertFilename)
+	if !vsCode {
+		actions.AddCommand(e, c, tty, status, bookmark, undo, "Insert \""+insertFilename+"\" at the current line", "insertfile", insertFilename)
 
-	actions.Add("Toggle column limit indicator", func() {
-		e.showColumnLimit = !e.showColumnLimit
-	})
+		actions.Add("Toggle column limit indicator", func() {
+			e.showColumnLimit = !e.showColumnLimit
+		})
 
-	// Word wrap at a custom width + enable word wrap when typing
-	actions.Add("Word wrap at...", func() {
-		const tabInputText = "79"
-		if wordWrapString, ok := e.UserInput(c, tty, status, fmt.Sprintf("Word wrap at [%d]", wrapWidth), "", []string{}, false, tabInputText); ok {
-			if strings.TrimSpace(wordWrapString) == "" {
-				e.WrapNow(wrapWidth)
-				e.wrapWhenTyping = true
-				status.SetMessageAfterRedraw(fmt.Sprintf("Word wrap at %d", wrapWidth))
-			} else {
-				if ww, err := strconv.Atoi(wordWrapString); err != nil {
-					status.Clear(c, false)
-					status.SetError(err)
-					status.Show(c, e)
-				} else {
-					e.WrapNow(ww)
+		// Word wrap at a custom width + enable word wrap when typing
+		actions.Add("Word wrap at...", func() {
+			const tabInputText = "79"
+			if wordWrapString, ok := e.UserInput(c, tty, status, fmt.Sprintf("Word wrap at [%d]", wrapWidth), "", []string{}, false, tabInputText); ok {
+				if strings.TrimSpace(wordWrapString) == "" {
+					e.WrapNow(wrapWidth)
 					e.wrapWhenTyping = true
 					status.SetMessageAfterRedraw(fmt.Sprintf("Word wrap at %d", wrapWidth))
+				} else {
+					if ww, err := strconv.Atoi(wordWrapString); err != nil {
+						status.Clear(c, false)
+						status.SetError(err)
+						status.Show(c, e)
+					} else {
+						e.WrapNow(ww)
+						e.wrapWhenTyping = true
+						status.SetMessageAfterRedraw(fmt.Sprintf("Word wrap at %d", wrapWidth))
+					}
 				}
 			}
-		}
-	})
+		})
+	}
 
-	// Build (for use on the terminal, since ctrl-space does not work on iTerm2 + macOS)
-	if isDarwin && !inVTEGUI {
+	if !vsCode {
 		var alsoRun = false
 		var menuItemText = "Export"
-		if e.ProgrammingLanguage() {
+		if ProgrammingLanguage(e.mode) {
 			if e.CanRun() {
 				alsoRun = true
 				menuItemText = "Build and run"
@@ -170,8 +178,8 @@ func (e *Editor) CommandMenu(c *vt100.Canvas, tty *vt100.TTY, status *StatusBar,
 			}
 		}
 		actions.Add(menuItemText, func() {
-			const markdownDoubleSpacePrevention = false
-			e.Build(c, status, tty, alsoRun, markdownDoubleSpacePrevention)
+			e.runAfterBuild = alsoRun
+			e.Build(c, status, tty)
 		})
 	}
 
@@ -305,55 +313,62 @@ func (e *Editor) CommandMenu(c *vt100.Canvas, tty *vt100.TTY, status *StatusBar,
 		// TODO: Detect if file is locked first
 		actions.Add("Unlock if locked", func() {
 			if absFilename, err := e.AbsFilename(); err == nil { // no issues
-				lk.Load()
-				lk.Unlock(absFilename)
-				lk.Save()
+				go func() {
+					quitMut.Lock()
+					defer quitMut.Unlock()
+					fileLock.Load()
+					fileLock.Unlock(absFilename)
+					fileLock.Save()
+				}()
 			}
 		})
 	}
 
-	// Render to PDF using the gofpdf package
-	actions.Add("Render to PDF", func() {
-		// Write to PDF in a goroutine
-		pdfFilename := strings.ReplaceAll(filepath.Base(e.filename), ".", "_") + ".pdf"
+	if !vsCode {
 
-		// Show a status message while writing
-		status.SetMessage("Writing " + pdfFilename + "...")
-		status.ShowNoTimeout(c, e)
+		// Render to PDF using the gofpdf package
+		actions.Add("Render to PDF", func() {
+			// Write to PDF in a goroutine
+			pdfFilename := strings.ReplaceAll(filepath.Base(e.filename), ".", "_") + ".pdf"
 
-		statusMessage := ""
+			// Show a status message while writing
+			status.SetMessage("Writing " + pdfFilename + "...")
+			status.ShowNoTimeout(c, e)
 
-		// TODO: Only overwrite if the previous PDF file was also rendered by "o".
-		_ = os.Remove(pdfFilename)
-		// Write the file
-		if err := e.SavePDF(e.filename, pdfFilename); err != nil {
-			statusMessage = err.Error()
-		} else {
-			statusMessage = "Wrote " + pdfFilename
-		}
-		// Show a status message after writing
-		status.ClearAll(c, true)
-		status.SetMessage(statusMessage)
-		status.ShowNoTimeout(c, e)
-	})
+			statusMessage := ""
 
-	// Render to PDF using pandoc
-	if (e.mode == mode.Markdown || e.mode == mode.ASCIIDoc || e.mode == mode.SCDoc) && files.WhichCached("pandoc") != "" {
-		actions.Add("Render to PDF using pandoc", func() {
-			// pandoc
-			if pandocPath := files.WhichCached("pandoc"); pandocPath != "" {
-				pdfFilename := strings.ReplaceAll(filepath.Base(e.filename), ".", "_") + ".pdf"
-				go func() {
-					pandocMutex.Lock()
-					_ = e.exportPandocPDF(c, tty, status, pandocPath, pdfFilename)
-					pandocMutex.Unlock()
-				}()
-				// the exportPandoc function handles it's own status output
-				return
+			// TODO: Only overwrite if the previous PDF file was also rendered by "o".
+			_ = os.Remove(pdfFilename)
+			// Write the file
+			if err := e.SavePDF(e.filename, pdfFilename); err != nil {
+				statusMessage = err.Error()
+			} else {
+				statusMessage = "Wrote " + pdfFilename
 			}
-			status.SetErrorMessage("Could not find pandoc")
+			// Show a status message after writing
+			status.ClearAll(c, true)
+			status.SetMessage(statusMessage)
 			status.ShowNoTimeout(c, e)
 		})
+
+		// Render to PDF using pandoc
+		if (e.mode == mode.Markdown || e.mode == mode.ASCIIDoc || e.mode == mode.SCDoc) && files.WhichCached("pandoc") != "" {
+			actions.Add("Render to PDF using pandoc", func() {
+				// pandoc
+				if pandocPath := files.WhichCached("pandoc"); pandocPath != "" {
+					pdfFilename := strings.ReplaceAll(filepath.Base(e.filename), ".", "_") + ".pdf"
+					go func() {
+						pandocMutex.Lock()
+						_ = e.exportPandocPDF(c, tty, status, pandocPath, pdfFilename)
+						pandocMutex.Unlock()
+					}()
+					// the exportPandoc function handles it's own status output
+					return
+				}
+				status.SetErrorMessage("Could not find pandoc")
+				status.ShowNoTimeout(c, e)
+			})
+		}
 	}
 
 	// This is a bit odd, but useful when copying the file in 200 line chunks.
@@ -372,6 +387,7 @@ func (e *Editor) CommandMenu(c *vt100.Canvas, tty *vt100.TTY, status *StatusBar,
 				"Teal           (O_THEME=teal)",
 				"Blue Edit      (O_THEME=blueedit)",
 				"Pinetree       (O_THEME=pinetree)",
+				"Zulu           (O_THEME=zulu)",
 				"Gray Mono      (O_THEME=graymono)",
 				"Amber Mono     (O_THEME=ambermono)",
 				"Green Mono     (O_THEME=greenmono)",
@@ -430,23 +446,27 @@ func (e *Editor) CommandMenu(c *vt100.Canvas, tty *vt100.TTY, status *StatusBar,
 				envNoColor = false
 				e.SetTheme(NewPinetreeTheme())
 				e.syntaxHighlight = true
-			case 9: // Gray Mono
+			case 9: // Zulu
+				envNoColor = false
+				e.SetTheme(NewZuluTheme())
+				e.syntaxHighlight = true
+			case 10: // Gray Mono
 				envNoColor = false
 				e.setGrayTheme()
 				e.syntaxHighlight = false
-			case 10: // Amber Mono
+			case 11: // Amber Mono
 				envNoColor = false
 				e.setAmberTheme()
 				e.syntaxHighlight = false
-			case 11: // Green Mono
+			case 12: // Green Mono
 				envNoColor = false
 				e.setGreenTheme()
 				e.syntaxHighlight = false
-			case 12: // Blue Mono
+			case 13: // Blue Mono
 				envNoColor = false
 				e.setBlueTheme()
 				e.syntaxHighlight = false
-			case 13: // No color
+			case 14: // No color
 				envNoColor = true
 				e.setNoColorTheme()
 				e.syntaxHighlight = false
@@ -461,17 +481,28 @@ func (e *Editor) CommandMenu(c *vt100.Canvas, tty *vt100.TTY, status *StatusBar,
 
 	// Add a menu item to toggle primary/non-primary clipboard on Linux
 	if isLinux {
-		primaryToggleText := "Use the secondary clipboard instead"
+		primaryToggleText := "Switch to the secondary clipboard"
 		if !e.primaryClipboard {
-			primaryToggleText = "Use the primary clipboard instead"
+			primaryToggleText = "Switch to the primary clipboard"
 		}
 		actions.Add(primaryToggleText, func() {
 			e.primaryClipboard = !e.primaryClipboard
 		})
 	}
 
-	if !e.EmptyLine() {
-		actions.AddCommand(e, c, tty, status, bookmark, undo, "Split line on blanks outside of (), [] or {}", "splitline")
+	if !vsCode {
+		if !e.EmptyLine() {
+			actions.AddCommand(e, c, tty, status, bookmark, undo, "Split line on blanks outside of (), [] or {}", "splitline")
+		}
+		if e.moveLinesMode.Load() {
+			actions.Add("Move the cursor with ctrl-n and ctrl-p", func() {
+				e.moveLinesMode.Store(false)
+			})
+		} else {
+			actions.Add("Move lines with ctrl-n and ctrl-p", func() {
+				e.moveLinesMode.Store(true)
+			})
+		}
 	}
 
 	// Only show the menu option for killing the parent process if the parent process is a known search command
@@ -479,16 +510,14 @@ func (e *Editor) CommandMenu(c *vt100.Canvas, tty *vt100.TTY, status *StatusBar,
 	if firstWordContainsOneOf(parentCommand(), searchProcessNames) {
 		actions.Add("Kill parent and exit without saving", func() {
 			e.stopParentOnQuit = true
-			e.clearOnQuit = true
-			e.quit = true        // indicate that the user wishes to quit
-			e.clearOnQuit = true // clear the terminal after quitting
+			e.quit = true           // indicate that the user wishes to quit
+			clearOnQuit.Store(true) // clear the terminal after quitting
 		})
 	} else {
 		actions.Add("Exit without saving", func() {
 			e.stopParentOnQuit = false
-			e.clearOnQuit = false
-			e.quit = true        // indicate that the user wishes to quit
-			e.clearOnQuit = true // clear the terminal after quitting
+			e.quit = true           // indicate that the user wishes to quit
+			clearOnQuit.Store(true) // clear the terminal after quitting
 		})
 	}
 
