@@ -12,14 +12,14 @@ import (
 
 	"github.com/xyproto/clip"
 	"github.com/xyproto/files"
-	"github.com/xyproto/vt100"
+	"github.com/xyproto/vt"
 )
 
 const commandTimeout = 10 * time.Second
 
 // CommandToFunction takes an editor command as a string (with optional arguments) and returns a function that
 // takes no arguments and performs the suggested action, like "save". Some functions may take an undo snapshot first.
-func (e *Editor) CommandToFunction(c *vt100.Canvas, tty *vt100.TTY, status *StatusBar, bookmark *Position, undo *Undo, args ...string) (func(), error) {
+func (e *Editor) CommandToFunction(c *vt.Canvas, tty *vt.TTY, status *StatusBar, bookmark *Position, undo *Undo, args ...string) (func(), error) {
 	if len(args) == 0 {
 		return nil, errors.New("no command given")
 	}
@@ -271,9 +271,15 @@ func (e *Editor) CommandToFunction(c *vt100.Canvas, tty *vt100.TTY, status *Stat
 		insertfile: func() { // insert a file
 			undo.Snapshot(e)
 			editedFileDir := filepath.Dir(e.filename)
-			if err := e.InsertFile(c, filepath.Join(editedFileDir, strings.TrimSpace(args[1]))); err != nil {
-				e.redraw.Store(true)
-				status.SetErrorAfterRedraw(err)
+			filename2 := strings.TrimSpace(args[1])              // include.txt
+			filename1 := filepath.Join(editedFileDir, filename2) // include.txt in the same dir as the edited file
+			// First try inserting include.txt from the same directory as the edited file,
+			// then try inserting include.txt from the current directory.
+			if err := e.InsertFile(c, filename1); err != nil {
+				if err2 := e.InsertFile(c, filename2); err2 != nil {
+					e.redraw.Store(true)
+					status.SetErrorAfterRedraw(err2)
+				}
 			}
 		},
 		inserttime: func() { // insert the current time
@@ -319,7 +325,7 @@ func (e *Editor) CommandToFunction(c *vt100.Canvas, tty *vt100.TTY, status *Stat
 		savequitclear: func() { // save and quit, then clear the screen
 			e.UserSave(c, tty, status)
 			e.quit = true
-			e.clearOnQuit = true
+			clearOnQuit.Store(true)
 		},
 		sortblock: func() { // sort the current block of lines, until the next blank line or EOF
 			undo.Snapshot(e)
@@ -415,7 +421,7 @@ func (e *Editor) CommandToFunction(c *vt100.Canvas, tty *vt100.TTY, status *Stat
 }
 
 // RunCommand takes a command string and performs and action (like "save" or "quit")
-func (e *Editor) RunCommand(c *vt100.Canvas, tty *vt100.TTY, status *StatusBar, bookmark *Position, undo *Undo, args ...string) error {
+func (e *Editor) RunCommand(c *vt.Canvas, tty *vt.TTY, status *StatusBar, bookmark *Position, undo *Undo, args ...string) error {
 	f, err := e.CommandToFunction(c, tty, status, bookmark, undo, args...)
 	if err != nil {
 		return err
@@ -426,7 +432,7 @@ func (e *Editor) RunCommand(c *vt100.Canvas, tty *vt100.TTY, status *StatusBar,
 
 // CommandPrompt shows and handles user input that is interpreted as internal commands,
 // or external commands if they start with "!"
-func (e *Editor) CommandPrompt(c *vt100.Canvas, tty *vt100.TTY, status *StatusBar, bookmark *Position, undo *Undo) {
+func (e *Editor) CommandPrompt(c *vt.Canvas, tty *vt.TTY, status *StatusBar, bookmark *Position, undo *Undo) {
 	// The spaces are intentional, to stop the shorter strings from always kicking in before
 	// the longer ones can be typed.
 	quickList := []string{":wq", "wq", "sq", "sqc", ":q", "q", ":w ", "s ", "w ", "d", "b", "↑", "↓", "c:23", "c:19", "c:17"}
