@@ -3,12 +3,12 @@ package main
 import (
 	"bytes"
 	"errors"
+	"io"
 	"os"
 	"os/exec"
 	"strings"
 
 	"github.com/xyproto/files"
-	"github.com/xyproto/vt100"
 )
 
 // exportScdoc tries to export the current document as a manual page, using scdoc
@@ -30,6 +30,7 @@ func (e *Editor) exportScdoc(manFilename string) error {
 	if err != nil {
 		return err
 	}
+	defer manpageFile.Close()
 
 	var errBuf bytes.Buffer
 	scdoc.Stdout = manpageFile
@@ -50,19 +51,25 @@ func (e *Editor) exportScdoc(manFilename string) error {
 }
 
 // exportAdoc tries to export the current document as a manual page, using asciidoctor
-func (e *Editor) exportAdoc(c *vt100.Canvas, tty *vt100.TTY, manFilename string) error {
+func (e *Editor) exportAdoc(manFilename string) error {
 	adocPath := files.WhichCached("asciidoctor")
 	if adocPath == "" {
 		return errors.New("could not find asciidoctor in the PATH")
 	}
-
-	// TODO: Use a proper function for generating temporary files
-	tmpfn := "___o___.adoc"
-	if files.Exists(tmpfn) {
-		return errors.New(tmpfn + " already exists, please remove it")
+	tmpfile, err := os.CreateTemp("", "*.adoc")
+	if err != nil {
+		return err
 	}
+	tmpfn := tmpfile.Name()
 
-	e.SaveAs(c, tty, tmpfn)
+	defer func() {
+		tmpfile.Close()
+		os.Remove(tmpfn)
+	}()
+
+	if _, err := io.WriteString(tmpfile, e.String()); err != nil {
+		return err
+	}
 
 	// Run asciidoctor
 	adocCommand := exec.Command(adocPath, "-b", "manpage", "-o", manFilename, tmpfn)
