@@ -2,6 +2,7 @@ package main
 
 import (
 	"bytes"
+	"context"
 	"fmt"
 	"image"
 	"image/draw"
@@ -9,15 +10,13 @@ import (
 	"math"
 	"math/rand"
 	"os"
-	"os/signal"
 	"path/filepath"
 	"strconv"
 	"strings"
-	"syscall"
 	"time"
 
 	"github.com/xyproto/files"
-	"github.com/xyproto/vt100"
+	"github.com/xyproto/vt"
 )
 
 // There is a tradition for including silly little games in editors, so here goes:
@@ -39,33 +38,33 @@ var (
 	highScoreFile = filepath.Join(userCacheDir, "o", "highscore.txt")
 	gameTitle     = "Feed the gobblers! Keys: arrows, space and q"
 
-	bobColor             = vt100.LightYellow
-	bobWonColor          = vt100.LightGreen
-	bobLostColor         = vt100.Red
-	evilGobblerColor     = vt100.LightRed
-	gobblerColor         = vt100.Yellow
-	gobblerDeadColor     = vt100.DarkGray
-	gobblerZombieColor   = vt100.LightBlue
-	bubbleColor          = vt100.Magenta
-	pelletColor1         = vt100.LightGreen
-	pelletColor2         = vt100.Green
-	statusTextColor      = vt100.Black
-	statusTextBackground = vt100.Blue
-	resizeColor          = vt100.LightMagenta
-	gameBackgroundColor  = vt100.DefaultBackground
+	bobColor             = vt.LightYellow
+	bobWonColor          = vt.LightGreen
+	bobLostColor         = vt.Red
+	evilGobblerColor     = vt.LightRed
+	gobblerColor         = vt.Yellow
+	gobblerDeadColor     = vt.DarkGray
+	gobblerZombieColor   = vt.LightBlue
+	bubbleColor          = vt.Magenta
+	pelletColor1         = vt.LightGreen
+	pelletColor2         = vt.Green
+	statusTextColor      = vt.Black
+	statusTextBackground = vt.Blue
+	resizeColor          = vt.LightMagenta
+	gameBackgroundColor  = vt.DefaultBackground
 )
 
 // Bob represents the player
 type Bob struct {
-	color      vt100.AttributeColor // foreground color
-	x, y       int                  // current position
-	oldx, oldy int                  // previous position
+	x, y       int // current position
+	oldx, oldy int // previous position
 	w, h       float64
-	state      rune // looks
+	color      vt.AttributeColor // foreground color
+	state      rune              // looks
 }
 
 // NewBob creates a new Bob struct
-func NewBob(c *vt100.Canvas, startingWidth int) *Bob {
+func NewBob(c *vt.Canvas, startingWidth int) *Bob {
 	return &Bob{
 		x:     startingWidth / 20,
 		y:     10,
@@ -90,7 +89,7 @@ func (b *Bob) ToggleState() {
 }
 
 // Draw is called when Bob should be drawn on the canvas
-func (b *Bob) Draw(c *vt100.Canvas) {
+func (b *Bob) Draw(c *vt.Canvas) {
 	c.PlotColor(uint(b.x), uint(b.y), b.color, b.state)
 }
 
@@ -132,7 +131,7 @@ func (b *Bob) Up() bool {
 }
 
 // Down is called when Bob should move down
-func (b *Bob) Down(c *vt100.Canvas) bool {
+func (b *Bob) Down(c *vt.Canvas) bool {
 	oldy := b.y
 	b.y++
 	if b.y >= int(c.H()) {
@@ -145,7 +144,7 @@ func (b *Bob) Down(c *vt100.Canvas) bool {
 }
 
 // Resize is called when the terminal is resized
-func (b *Bob) Resize(c *vt100.Canvas) {
+func (b *Bob) Resize(c *vt.Canvas) {
 	b.color = resizeColor
 	b.w = float64(c.W())
 	b.h = float64(c.H())
@@ -153,7 +152,7 @@ func (b *Bob) Resize(c *vt100.Canvas) {
 
 // Pellet represents a pellet that can both feed Gobblers and hit the EvilGobbler
 type Pellet struct {
-	color       vt100.AttributeColor // foreground color
+	color       vt.AttributeColor // foreground color
 	lifeCounter int
 	oldx, oldy  int // previous position
 	vx, vy      int // velocity
@@ -165,7 +164,7 @@ type Pellet struct {
 }
 
 // NewPellet creates a new Pellet struct, with position and speed
-func NewPellet(c *vt100.Canvas, x, y, vx, vy int) *Pellet {
+func NewPellet(c *vt.Canvas, x, y, vx, vy int) *Pellet {
 	return &Pellet{
 		x:           x,
 		y:           y,
@@ -195,12 +194,12 @@ func (b *Pellet) ToggleColor() {
 }
 
 // Draw draws the Pellet on the canvas
-func (b *Pellet) Draw(c *vt100.Canvas) {
+func (b *Pellet) Draw(c *vt.Canvas) {
 	c.PlotColor(uint(b.x), uint(b.y), b.color, b.state)
 }
 
 // Next moves the object to the next position, and returns true if it moved
-func (b *Pellet) Next(c *vt100.Canvas, e *EvilGobbler) bool {
+func (b *Pellet) Next(c *vt.Canvas, e *EvilGobbler) bool {
 	b.lifeCounter++
 	if b.lifeCounter > 20 {
 		b.removed = true
@@ -258,7 +257,7 @@ func (b *Pellet) Stop() {
 }
 
 // HitSomething is called when the pellet hits something
-func (b *Pellet) HitSomething(c *vt100.Canvas) bool {
+func (b *Pellet) HitSomething(c *vt.Canvas) bool {
 	r, err := c.At(uint(b.x), uint(b.y))
 	if err != nil {
 		return false
@@ -278,7 +277,7 @@ func (b *Pellet) HitSomething(c *vt100.Canvas) bool {
 }
 
 // Resize is called when the terminal is resized
-func (b *Pellet) Resize(c *vt100.Canvas) {
+func (b *Pellet) Resize(c *vt.Canvas) {
 	b.stopped = false
 	b.w = float64(c.W())
 	b.h = float64(c.H())
@@ -286,15 +285,15 @@ func (b *Pellet) Resize(c *vt100.Canvas) {
 
 // Bubble represents a bubble character that is in the way
 type Bubble struct {
-	color      vt100.AttributeColor // foreground color
-	x, y       int                  // current position
-	oldx, oldy int                  // previous position
+	x, y       int // current position
+	oldx, oldy int // previous position
 	w, h       float64
-	state      rune // looks
+	color      vt.AttributeColor // foreground color
+	state      rune              // looks
 }
 
 // NewBubbles creates n new Bubble structs
-func NewBubbles(c *vt100.Canvas, startingWidth int, n int) []*Bubble {
+func NewBubbles(c *vt.Canvas, startingWidth int, n int) []*Bubble {
 	bubbles := make([]*Bubble, n)
 	for i := range bubbles {
 		bubbles[i] = NewBubble(c, startingWidth)
@@ -303,7 +302,7 @@ func NewBubbles(c *vt100.Canvas, startingWidth int, n int) []*Bubble {
 }
 
 // NewBubble creates a new Bubble struct
-func NewBubble(c *vt100.Canvas, startingWidth int) *Bubble {
+func NewBubble(c *vt.Canvas, startingWidth int) *Bubble {
 	return &Bubble{
 		x:     startingWidth / 5,
 		y:     10,
@@ -317,19 +316,19 @@ func NewBubble(c *vt100.Canvas, startingWidth int) *Bubble {
 }
 
 // Draw draws the Bubble on the canvas
-func (b *Bubble) Draw(c *vt100.Canvas) {
+func (b *Bubble) Draw(c *vt.Canvas) {
 	c.PlotColor(uint(b.x), uint(b.y), b.color, b.state)
 }
 
 // Resize is called when the terminal is resized
-func (b *Bubble) Resize(c *vt100.Canvas) {
+func (b *Bubble) Resize(c *vt.Canvas) {
 	b.color = resizeColor
 	b.w = float64(c.W())
 	b.h = float64(c.H())
 }
 
 // Next moves the object to the next position, and returns true if it moved
-func (b *Bubble) Next(c *vt100.Canvas, bob *Bob, gobblers *[]*Gobbler) bool {
+func (b *Bubble) Next(c *vt.Canvas, bob *Bob, gobblers *[]*Gobbler) bool {
 	b.oldx = b.x
 	b.oldy = b.y
 
@@ -392,7 +391,7 @@ func (b *Bubble) Next(c *vt100.Canvas, bob *Bob, gobblers *[]*Gobbler) bool {
 }
 
 // HitSomething is called if the Bubble hits another character
-func (b *Bubble) HitSomething(c *vt100.Canvas) bool {
+func (b *Bubble) HitSomething(c *vt.Canvas) bool {
 	r, err := c.At(uint(b.x), uint(b.y))
 	if err != nil {
 		return false
@@ -404,9 +403,9 @@ func (b *Bubble) HitSomething(c *vt100.Canvas) bool {
 // EvilGobbler is a character that hunts Gobblers
 type EvilGobbler struct {
 	hunting         *Gobbler
-	color           vt100.AttributeColor // foreground color
-	x, y            int                  // current position
-	oldx, oldy      int                  // previous position
+	color           vt.AttributeColor // foreground color
+	x, y            int               // current position
+	oldx, oldy      int               // previous position
 	counter         uint
 	huntingDistance float64
 	w, h            float64
@@ -416,7 +415,7 @@ type EvilGobbler struct {
 
 // NewEvilGobbler creates an EvilGobbler struct.
 // startingWidth is the initial width of the canvas.
-func NewEvilGobbler(c *vt100.Canvas, startingWidth int) *EvilGobbler {
+func NewEvilGobbler(c *vt.Canvas, startingWidth int) *EvilGobbler {
 	return &EvilGobbler{
 		x:               startingWidth/2 + 5,
 		y:               0o1,
@@ -434,12 +433,12 @@ func NewEvilGobbler(c *vt100.Canvas, startingWidth int) *EvilGobbler {
 }
 
 // Draw will draw the EvilGobbler on the canvas
-func (e *EvilGobbler) Draw(c *vt100.Canvas) {
+func (e *EvilGobbler) Draw(c *vt.Canvas) {
 	c.PlotColor(uint(e.x), uint(e.y), e.color, e.state)
 }
 
 // Next will make the next EvilGobbler move
-func (e *EvilGobbler) Next(c *vt100.Canvas, gobblers *[]*Gobbler) bool {
+func (e *EvilGobbler) Next(c *vt.Canvas, gobblers *[]*Gobbler) bool {
 	e.oldx = e.x
 	e.oldy = e.y
 
@@ -501,7 +500,7 @@ func (e *EvilGobbler) Next(c *vt100.Canvas, gobblers *[]*Gobbler) bool {
 }
 
 // Resize is called when the terminal is resized
-func (e *EvilGobbler) Resize(c *vt100.Canvas) {
+func (e *EvilGobbler) Resize(c *vt.Canvas) {
 	e.color = resizeColor
 	e.w = float64(c.W())
 	e.h = float64(c.H())
@@ -509,11 +508,11 @@ func (e *EvilGobbler) Resize(c *vt100.Canvas) {
 
 // Gobbler represents a character that can move around and eat pellets
 type Gobbler struct {
-	hunting         *Pellet              // current pellet to hunt
-	color           vt100.AttributeColor // foreground color
-	x, y            int                  // current position
-	oldx, oldy      int                  // previous position
-	huntingDistance float64              // how far to closest pellet
+	hunting         *Pellet           // current pellet to hunt
+	color           vt.AttributeColor // foreground color
+	x, y            int               // current position
+	oldx, oldy      int               // previous position
+	huntingDistance float64           // how far to closest pellet
 	counter         uint
 	w, h            float64
 	state           rune // looks
@@ -521,7 +520,7 @@ type Gobbler struct {
 }
 
 // NewGobbler creates a new Gobbler struct
-func NewGobbler(c *vt100.Canvas, startingWidth int) *Gobbler {
+func NewGobbler(c *vt.Canvas, startingWidth int) *Gobbler {
 	return &Gobbler{
 		x:               startingWidth / 2,
 		y:               10,
@@ -539,7 +538,7 @@ func NewGobbler(c *vt100.Canvas, startingWidth int) *Gobbler {
 }
 
 // NewGobblers creates n new Gobbler structs
-func NewGobblers(c *vt100.Canvas, startingWidth int, n int) []*Gobbler {
+func NewGobblers(c *vt.Canvas, startingWidth int, n int) []*Gobbler {
 	gobblers := make([]*Gobbler, n)
 	for i := range gobblers {
 		gobblers[i] = NewGobbler(c, startingWidth)
@@ -548,7 +547,7 @@ func NewGobblers(c *vt100.Canvas, startingWidth int, n int) []*Gobbler {
 }
 
 // Draw draws the current Gobbler on the canvas
-func (g *Gobbler) Draw(c *vt100.Canvas) {
+func (g *Gobbler) Draw(c *vt.Canvas) {
 	c.PlotColor(uint(g.x), uint(g.y), g.color, g.state)
 }
 
@@ -674,7 +673,7 @@ func (g *Gobbler) Next(pellets *[]*Pellet, bob *Bob) bool {
 }
 
 // Resize is called when the terminal is resized
-func (g *Gobbler) Resize(c *vt100.Canvas) {
+func (g *Gobbler) Resize(c *vt.Canvas) {
 	g.color = resizeColor
 	g.w = float64(c.W())
 	g.h = float64(c.H())
@@ -689,7 +688,7 @@ func saveHighScore(highScore uint) error {
 	}
 	// First create the folders, if needed
 	folderPath := filepath.Dir(highScoreFile)
-	os.MkdirAll(folderPath, os.ModePerm)
+	_ = os.MkdirAll(folderPath, 0o755)
 	// Prepare the file
 	f, err := os.OpenFile(highScoreFile, os.O_WRONLY|os.O_CREATE|os.O_TRUNC, 0o600)
 	if err != nil {
@@ -720,33 +719,33 @@ func loadHighScore() (uint, error) {
 func Game() (bool, error) {
 retry:
 	if envNoColor {
-		bobColor = vt100.White
-		bobWonColor = vt100.LightGray
-		bobLostColor = vt100.DarkGray
-		evilGobblerColor = vt100.White
-		gobblerColor = vt100.LightGray
-		gobblerDeadColor = vt100.DarkGray
-		bubbleColor = vt100.DarkGray
-		pelletColor1 = vt100.White
-		pelletColor2 = vt100.White
-		statusTextColor = vt100.Black
-		statusTextBackground = vt100.LightGray
-		resizeColor = vt100.White
-		gameBackgroundColor = vt100.DefaultBackground
+		bobColor = vt.White
+		bobWonColor = vt.LightGray
+		bobLostColor = vt.DarkGray
+		evilGobblerColor = vt.White
+		gobblerColor = vt.LightGray
+		gobblerDeadColor = vt.DarkGray
+		bubbleColor = vt.DarkGray
+		pelletColor1 = vt.White
+		pelletColor2 = vt.White
+		statusTextColor = vt.Black
+		statusTextBackground = vt.LightGray
+		resizeColor = vt.White
+		gameBackgroundColor = vt.DefaultBackground
 	} else {
-		statusTextBackground = vt100.Blue
-		bobColor = vt100.LightYellow
+		statusTextBackground = vt.Blue
+		bobColor = vt.LightYellow
 	}
 
 	// Try loading the highscore from the file, but ignore any errors
 	highScore, _ := loadHighScore()
 
-	c := vt100.NewCanvas()
+	c := vt.NewCanvas()
 	c.FillBackground(gameBackgroundColor)
 
-	tty, err := vt100.NewTTY()
+	tty, err := vt.NewTTY()
 	if err != nil {
-		fmt.Fprintln(os.Stderr, "error: "+err.Error())
+		fmt.Fprintln(os.Stderr, err)
 		quitMut.Lock()
 		defer quitMut.Unlock()
 		os.Exit(1)
@@ -766,39 +765,50 @@ retry:
 		score         = uint(0)
 	)
 
-	signal.Notify(sigChan, syscall.SIGWINCH)
-	go func() {
-		for range sigChan {
-			resizeMut.Lock()
-			// Create a new canvas, with the new size
-			nc := c.Resized()
-			if nc != nil {
-				c.Clear()
-				vt100.Clear()
-				c.HideCursorAndDraw()
-				c = nc
-			}
+	setupResizeSignal(sigChan)
 
-			// Inform all elements that the terminal was resized
-			// TODO: Use a slice of interfaces that can contain all elements
-			for _, pellet := range pellets {
-				pellet.Resize(c)
+	ctx, cancelFunc := context.WithCancel(context.Background())
+
+	// Cleanup function to be called on function exit
+	defer func() {
+		cancelFunc()
+		resetResizeSignal()
+	}()
+
+	go func() {
+		for {
+			select {
+			case <-sigChan:
+				resizeMut.Lock()
+				nc := c.Resized()
+				if nc != nil {
+					c.Clear()
+					vt.Clear()
+					c.HideCursorAndDraw()
+					c = nc
+				}
+
+				for _, pellet := range pellets {
+					pellet.Resize(c)
+				}
+				for _, bubble := range bubbles {
+					bubble.Resize(c)
+				}
+				for _, gobbler := range gobblers {
+					gobbler.Resize(c)
+				}
+				bob.Resize(c)
+				evilGobbler.Resize(c)
+				resizeMut.Unlock()
+			case <-ctx.Done():
+				return
 			}
-			for _, bubble := range bubbles {
-				bubble.Resize(c)
-			}
-			for _, gobbler := range gobblers {
-				gobbler.Resize(c)
-			}
-			bob.Resize(c)
-			evilGobbler.Resize(c)
-			resizeMut.Unlock()
 		}
 	}()
 
-	vt100.Init()
-	vt100.EchoOff()
-	defer vt100.Close()
+	vt.Init()
+	vt.EchoOff()
+	defer vt.Close()
 
 	// The loop time that is aimed for
 	var (
@@ -856,7 +866,7 @@ retry:
 		c.Write(0, 0, statusTextColor, statusTextBackground, statusLine)
 		resizeMut.RUnlock()
 
-		// vt100.Clear()
+		// Clear()
 
 		// Update the canvas
 		c.HideCursorAndDraw()
