@@ -4,7 +4,7 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/xyproto/vt100"
+	"github.com/xyproto/vt"
 )
 
 const (
@@ -22,6 +22,8 @@ Overview of hotkeys    ctrl-l and then /
 Launch tutorial        ctrl-l and then ?
 Disable this overview  ctrl-l and then !`
 
+	ollamaHelpText = "Ollama"
+
 	usageText = `Hotkeys
 
 ctrl-s      to save
@@ -35,17 +37,18 @@ ctrl-w      for Zig, Rust, V and Go, format with the "... fmt" command
             for HTML, format the file with "tidy", for Python: "black"
             for Markdown, toggle checkboxes or re-format tables
             for git interactive rebases, cycle the rebase keywords
-ctrl-g      jump to definition (experimental feature) or toggle the status bar
-ctrl-_      jump to a matching parenthesis or bracket if on one,
-            otherwise insert a symbol by typing in a two letter ViM-style digraph
+ctrl-g      jump to include, definition (experimental), back or toggle the status bar
+ctrl-_      insert a symbol by typing in a two letter ViM-style digraph
             see https://raw.githubusercontent.com/xyproto/digraph/main/digraphs.txt
 ctrl-a      go to start of line, then start of text and then the previous line
 ctrl-e      go to end of line and then the next line
 ctrl-n      to scroll down 10 lines or go to the next match if a search is active
             insert a column when in the Markdown table editor
             go to next match when searching, or next typo when spellchecking
+            jump to a matching parenthesis or bracket if the arrow keys were just used
 ctrl-p      to scroll up 10 lines or go to the previous match
             remove an empty column when in the Markdown table editor
+            jump to a matching parenthesis or bracket if the arrow keys were just used
 ctrl-k      to delete characters to the end of the line, then delete the line
 ctrl-j      to join lines
 ctrl-d      to delete a single character
@@ -54,9 +57,10 @@ ctrl-t      for C and C++, toggle between the header and implementation,
             for Agda, insert a symbol,
             for the rest, record and then play back a macro
 ctrl-c      to copy the current line, press twice to copy the current block
+            press thrice to copy the current function
 ctrl-v      to paste one line, press twice to paste the rest
 ctrl-x      to cut the current line, press twice to cut the current block
-ctrl-b      to jump back after having jumped to a definition
+ctrl-b      to jump back after having jumped to a definition or include
             to toggle a bookmark for the current line, or jump to a bookmark
             to toggle a breakpoint if in debug mode
 ctrl-u      to undo (ctrl-z is also possible, but may background the application)
@@ -64,32 +68,37 @@ ctrl-l      to jump to a specific line or letter (press return to jump to the to
 ctrl-f      to find text. To search and replace, press Tab instead of Return.
             to spellcheck, search for "t", then press ctrl-a to add and ctrl-i to ignore
 ctrl-\      to toggle single-line comments for a block of code
-ctrl-~      to jump to matching parenthesis
+ctrl-~      insert the current date and time
 esc         to redraw the screen, clear the last search and clear the current macro
 
 Set NO_COLOR=1 to disable colors.
 
 Flags:
   -c, --copy FILENAME            Copy the given file into the clipboard.
-  -f, --force                    Ignore file locks when opening files.
-  -l, --last-command             Output the last used build/format/export command.
-  -m, --monitor FILENAME         Monitor the given file for changes, and open it as read-only.
-  -n, --no-cache                 Avoid writing the location history, search history, highscore,
-                                 compilation and format command to ` + cacheDirForDoc + `.
   -p, --paste FILENAME           Paste the contents of the clipboard into the given file.
                                  Combine with -f to overwrite the file.
-  -q, --quick-help               Display the quick help pane at start.
-  -a, --nano                     Emulate Pico/Nano.
-  -r, --clear-locks              Clear all file locks and close all portals.
+  -f, --force                    Ignore file locks when opening files.
+  -l, --last-command             Output the last used build/format/export command.
+  -e, --clear-locks              Clear all file locks and close all portals.
+  -m, --monitor FILENAME         Monitor the given file for changes, and open it as read-only.
+  -o, --ollama                   Use $OLLAMA$
+                                 to explain the function under the cursor.
+  -r, --release                  Build with release instead of debug mode whenever applicable.
+  -x, --noapprox                 Disable approximate filename matching.
+  -n, --no-cache                 Avoid writing the location history, search history, highscore,
+                                 compilation and format command to ` + cacheDirForDoc + `.
   -d, --create-dir               When opening a new file, create directories as needed.
-  -g, --digraphs                 List all possible digraphs.
+  -s, --digraphs                 List all possible digraphs.
+  -t, --list                     List the given file using the red/black theme and quit.
+  -b, --bat                      List the given file using bat, if it exists in the PATH.
+                                 This can be useful when used with together with -c or -p.
   -i, --input-file FILENAME      Used as stdin when running programs with ctrl-space.
                                  The default filename is input.txt. Handy for Advent of Code.
-  -o, --ollama                   Use Ollama and the ` + codeCompletionModel + ` model
-                                 for tab completion (experimental feature).
-  -b, --bat                      List the given file using bat, if it exists in the PATH.
-                                 This can be useful in connection with -c or -p.
-  -t, --list                     List the given file using the red/black theme.
+  -a, --nano                     Emulate Pico/Nano.
+  -q, --quick-help               Always display the quick help pane at start.
+  -z, --no-quick-help            Never display the quick help pane at start.
+  -g, --glob GLOB                Search for and open the first filename that matches the substring.
+  -h, --help                     Display this usage information.
   -v, --version                  Display the current version.
 
 See the man page for more information.
@@ -100,11 +109,11 @@ See the man page for more information.
 // Usage prints the text that appears when the --help flag is passed
 func Usage() {
 	fmt.Println(versionString + " - simple and limited text editor")
-	fmt.Print(usageText)
+	fmt.Print(strings.Replace(usageText, "$OLLAMA$", ollamaHelpText, 1))
 }
 
 // DrawNanoHelp will draw a help box for nano hotkeys in the center
-func (e *Editor) DrawNanoHelp(c *vt100.Canvas, repositionCursorAfterDrawing bool) {
+func (e *Editor) DrawNanoHelp(c *vt.Canvas, repositionCursorAfterDrawing bool) {
 	const (
 		maxLines     = 30
 		title        = "Orbiton Nano Mode"
@@ -189,7 +198,7 @@ ctrl-l    - refresh the current screen
 }
 
 // DrawHotkeyOverview shows an overview of Orbiton hotkeys
-func (e *Editor) DrawHotkeyOverview(tty *vt100.TTY, c *vt100.Canvas, status *StatusBar, repositionCursorAfterDrawing bool) {
+func (e *Editor) DrawHotkeyOverview(tty *vt.TTY, c *vt.Canvas, status *StatusBar, repositionCursorAfterDrawing bool) {
 	const title = "Hotkey overview"
 
 	// Extracting hotkey information from usageText
