@@ -8,10 +8,17 @@ import (
 	"path/filepath"
 	"regexp"
 	"strings"
+	"sync"
 )
 
 var lastCommandFile = filepath.Join(userCacheDir, "o", "last_command.sh")
 
+// tmpFileStripRegex and tmpFileStripOnce cache the regex for stripping /tmp/o.* suffixes.
+var (
+	tmpFileStripRegex *regexp.Regexp
+	tmpFileStripOnce  sync.Once
+)
+
 // isProllyFilename checks if the argument is likely a filename based on the presence
 // of an OS-specific path separator and a ".".
 func isProllyFilename(arg string) bool {
@@ -45,7 +52,7 @@ func saveCommand(cmd *exec.Cmd) error {
 
 	// First create the folder for the lock file overview, if needed
 	folderPath := filepath.Dir(p)
-	os.MkdirAll(folderPath, os.ModePerm)
+	_ = os.MkdirAll(folderPath, 0o755)
 
 	// Prepare the file
 	f, err := os.OpenFile(p, os.O_WRONLY|os.O_CREATE|os.O_TRUNC, 0o600)
@@ -57,6 +64,14 @@ func saveCommand(cmd *exec.Cmd) error {
 	// Strip the leading /usr/bin/sh -c command, if present
 	commandString := getCommand(cmd)
 
+	// Add environment variables, but only some
+	selectedEnvVars := []string{"NO_COLOR", "PYTHON"}
+	for _, assignment := range cmd.Env {
+		if strings.Contains(assignment, "=") && containsSubstring(assignment, selectedEnvVars) {
+			commandString = strings.Replace(assignment, "=", "=\"", 1) + "\" \\\n" + commandString
+		}
+	}
+
 	// Write the contents, ignore the number of written bytes
 	_, err = f.WriteString(fmt.Sprintf("#!/bin/sh\n%s\n", commandString))
 	return err
@@ -74,6 +89,10 @@ func readLastCommand() (string, error) {
 		return "", fmt.Errorf("unrecognized contents in %s", lastCommandFile)
 	}
 	theRest := strings.TrimSpace(firstLineAndRest[1])
-	replaced := regexp.MustCompile(`/tmp/o\..*$`).ReplaceAllString(theRest, "")
+	// Strip out any /tmp/o.* suffix (cached regex compiled lazily)
+	tmpFileStripOnce.Do(func() {
+		tmpFileStripRegex = regexp.MustCompile(`/tmp/o\..*$`)
+	})
+	replaced := tmpFileStripRegex.ReplaceAllString(theRest, "")
 	return replaced, nil
 }
