@@ -9,21 +9,13 @@ import (
 	"sort"
 	"strconv"
 	"strings"
+	"sync"
 	"time"
-
-	"github.com/xyproto/env/v2"
 )
 
 const maxLocationHistoryEntries = 1024
 
-var (
-	userCacheDir                 = env.Dir("XDG_CACHE_HOME", "~/.cache")
-	locationHistoryFilename      = filepath.Join(userCacheDir, "o", "locations.txt")
-	vimLocationHistoryFilename   = env.ExpandUser("~/.viminfo")
-	emacsLocationHistoryFilename = env.ExpandUser("~/.emacs.d/places")
-	nvimLocationHistoryFilename  = filepath.Join(env.Dir("XDG_DATA_HOME", "~/.local/share"), "nvim", "shada", "main.shada")
-	locationHistory              LocationHistory // per absolute filename, for jumping to the last used line when opening a file
-)
+var locationHistory LocationHistory // per absolute filename, for jumping to the last used line when opening a file
 
 // LineNumberAndTimestamp contains both a LineNumber and a time.Time
 type LineNumberAndTimestamp struct {
@@ -71,7 +63,7 @@ func (locationHistory LocationHistory) Save(path string) error {
 	}
 	// First create the folder, if needed, in a best effort attempt
 	folderPath := filepath.Dir(path)
-	os.MkdirAll(folderPath, os.ModePerm)
+	_ = os.MkdirAll(folderPath, 0o755) // try to (re)create the directory, but ignore errors
 	var sb strings.Builder
 	for k, lineNumberAndTimestamp := range locationHistory {
 		lineNumber := lineNumberAndTimestamp.LineNumber
@@ -572,3 +564,31 @@ func (locationHistory LocationHistory) KeepNewest(n int) LocationHistory {
 
 	return newLocationHistory
 }
+
+// CloseLocksAndLocationHistory tries to close any active file locks and save the location history
+func (e *Editor) CloseLocksAndLocationHistory(absFilename string, lockTimestamp time.Time, forceFlag bool, wg *sync.WaitGroup) {
+	if canUseLocks.Load() {
+		wg.Add(1)
+		go func() {
+			// Start by loading the lock overview, just in case something has happened in the mean time
+			fileLock.Load()
+			// Check if the lock is unchanged
+			fileLockTimestamp := fileLock.GetTimestamp(absFilename)
+			lockUnchanged := lockTimestamp == fileLockTimestamp
+			// TODO: If the stored timestamp is older than uptime, unlock and save the lock overview
+			if !forceFlag || lockUnchanged {
+				// If the file has not been locked externally since this instance of the editor was loaded, don't
+				// Unlock the current file and save the lock overview. Ignore errors because they are not critical.
+				fileLock.Unlock(absFilename)
+				fileLock.Save()
+			}
+			wg.Done()
+		}()
+	}
+	// Save the current location in the location history and write it to file
+	wg.Add(1)
+	go func() {
+		e.SaveLocation(absFilename, locationHistory)
+		wg.Done()
+	}()
+}
