@@ -12,5 +12,5 @@ func abs(a int) int {
 
 // distance returns the distance between two points, given int
 func distance(x1, y1, x2, y2 int) float64 {
-	return math.Sqrt(float64((x1*x1 - x2*x2) + (y1*y1 - y2*y2)))
+	return math.Sqrt(float64((x1-x2)*(x1-x2) + (y1-y2)*(y1-y2)))
 }
