@@ -1,17 +1,16 @@
 package main
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"os"
-	"os/signal"
 	"strconv"
 	"strings"
-	"syscall"
 	"time"
 	"unicode"
 
-	"github.com/xyproto/vt100"
+	"github.com/xyproto/vt"
 )
 
 const konami = "↑↑↓↓←→←→ba"
@@ -136,14 +135,19 @@ func ctrlkey2letter(key string) (string, bool) {
 // -1 is "no choice", 0 and up is which choice were selected.
 // initialMenuIndex is the choice that should be highlighted when displaying the choices.
 // returns -1, true if space was pressed
-func (e *Editor) Menu(status *StatusBar, tty *vt100.TTY, title string, choices []string, bgColor, titleColor, arrowColor, textColor, highlightColor, selectedColor vt100.AttributeColor, initialMenuIndex int, extraDashes bool) (int, bool) {
+func (e *Editor) Menu(status *StatusBar, tty *vt.TTY, title string, choices []string, bgColor, titleColor, arrowColor, textColor, highlightColor, selectedColor vt.AttributeColor, initialMenuIndex int, extraDashes bool) (int, bool) {
+	notRegularEditingRightNow.Store(true)
+	defer func() {
+		notRegularEditingRightNow.Store(false)
+	}()
+
 	// Clear the existing handler
-	signal.Reset(syscall.SIGWINCH)
+	resetResizeSignal()
 
 	var (
 		selectionLetterMap = selectionLettersForChoices(choices)
 		selectedDelay      = 100 * time.Millisecond
-		c                  = vt100.NewCanvas()
+		c                  = vt.NewCanvas()
 		menu               = NewMenuWidget(title, choices, titleColor, arrowColor, textColor, highlightColor, selectedColor, c.W(), c.H(), extraDashes, selectionLetterMap)
 		sigChan            = make(chan os.Signal, 1)
 		running            = true
@@ -151,28 +155,39 @@ func (e *Editor) Menu(status *StatusBar, tty *vt100.TTY, title string, choices [
 	)
 
 	// Set up a new resize handler
-	signal.Notify(sigChan, syscall.SIGWINCH)
+	setupResizeSignal(sigChan)
+
+	ctx, cancelFunc := context.WithCancel(context.Background())
+
+	// Cleanup function to be called on function exit
+	defer func() {
+		cancelFunc()
+		resetResizeSignal()
+	}()
 
 	go func() {
-		for range sigChan {
-			resizeMut.Lock()
-			// Create a new canvas, with the new size
-			nc := c.Resized()
-			if nc != nil {
-				vt100.Clear()
-				c = nc
-				menu.Draw(c)
-				c.HideCursorAndRedraw()
-				changed = true
+		for {
+			select {
+			case <-sigChan:
+				resizeMut.Lock()
+				nc := c.Resized()
+				if nc != nil {
+					c.Clear()
+					vt.Clear()
+					c = nc
+					menu.Draw(c)
+					c.HideCursorAndRedraw()
+					changed = true
+				}
+				resizeMut.Unlock()
+			case <-ctx.Done():
+				return
 			}
-
-			// Inform all elements that the terminal was resized
-			resizeMut.Unlock()
 		}
 	}()
 
-	vt100.Clear()
-	vt100.Reset()
+	vt.Clear()
+	vt.Reset()
 	c.FillBackground(bgColor)
 	c.HideCursorAndRedraw()
 
