@@ -8,25 +8,32 @@ import (
 	"path/filepath"
 	"strconv"
 	"strings"
+	"sync/atomic"
 	"time"
 
 	"github.com/xyproto/env/v2"
 	"github.com/xyproto/files"
+	"github.com/xyproto/megafile"
 	"github.com/xyproto/mode"
-	"github.com/xyproto/vt100"
+	"github.com/xyproto/vt"
 )
 
 var (
-	specificLetter bool             // did the editor executable start with a specific letter, or just "o"?
-	editTheme      bool             // does the theme has both a dark and a light version?
-	inVTEGUI       = env.Bool("OG") // is o running within the VTE GUI application?
-	tempDir        = env.Dir("TMPDIR", "/tmp")
-	envNoColor     = env.Bool("NO_COLOR")
+	specificLetter    bool             // did the editor executable start with a specific letter, or just "o"?
+	editTheme         bool             // does the theme have both a dark and a light version?
+	inVTEGUI          = env.Bool("OG") // is o running within the VTE GUI application?
+	noDrawUntilResize atomic.Bool      // we are running within the VTE GUI application, but SIGWINCH has not been sent yet
+	tempDir           = env.Dir("TMPDIR", "/tmp")
+	errFileNotFound   = errors.New("file not found")
 )
 
 // NewEditor takes a filename and a line number to jump to (may be 0)
 // Returns an Editor, a status message for the user, a bool that is true if an image was displayed instead and the finally an error type.
-func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber LineNumber, colNumber ColNumber, theme Theme, origSyntaxHighlight, discoverBGColor, monitorAndReadOnly, nanoMode, createDirectoriesIfMissing, displayQuickHelp bool) (*Editor, string, bool, error) {
+func NewEditor(tty *vt.TTY, c *vt.Canvas, fnord FilenameOrData, lineNumber LineNumber, colNumber ColNumber, theme Theme, origSyntaxHighlight, discoverBGColor, monitorAndReadOnly, nanoMode, createDirectoriesIfMissing, displayQuickHelp, noDisplayQuickHelp bool) (*Editor, string, bool, error) {
+	if inVTEGUI {
+		noDrawUntilResize.Store(true)
+	}
+
 	var (
 		startTime          = time.Now()
 		createdNewFile     bool   // used for indicating that a new file was created
@@ -44,7 +51,7 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 
 	// Check if the given filename is an image
 	switch ext {
-	case ".png", ".jpg", ".jpeg", ".ico", ".gif", ".bmp", ".webp":
+	case ".png", ".jpg", ".jpeg", ".ico", ".gif", ".bmp", ".webp", ".qoi":
 		const waitForKeypress = true
 		return nil, "", true, displayImage(c, fnord.filename, waitForKeypress)
 	}
@@ -92,7 +99,8 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 		rainbowParenthesis,
 		monitorAndReadOnly,
 		createDirectoriesIfMissing,
-		displayQuickHelp)
+		displayQuickHelp,
+		noDisplayQuickHelp)
 
 	e.highlightCurrentText = !envNoColor
 
@@ -101,7 +109,7 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 	}
 
 	// For non-highlighted files, adjust the word wrap
-	if !e.syntaxHighlight {
+	if !e.syntaxHighlight && c != nil {
 		// Adjust the word wrap if the terminal is too narrow
 		w := int(c.Width())
 		if w < e.wrapWidth {
@@ -112,7 +120,7 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 	// Minor adjustments for some file types
 	switch e.mode {
 	case mode.Email, mode.Git, mode.ManPage:
-		e.clearOnQuit = true
+		clearOnQuit.Store(true)
 	}
 
 	// Set the editor filename
@@ -135,7 +143,7 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 
 		warningMessage, err = e.Load(c, tty, fnord)
 		if err != nil {
-			return nil, "", false, err
+			return e, "", false, err
 		}
 
 		if *parentIsMan {
@@ -146,7 +154,7 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 		// Markdown is set by default for some files.
 		// This corresponds to the check below, and both needs to be updated in sync.
 		// Also detect if Assembly could be Go/Plan9-style Assembly.
-		if e.mode == mode.Blank || e.mode == mode.Prolog || e.mode == mode.Config || e.mode == mode.Markdown || e.mode == mode.Assembly {
+		if e.mode == mode.Blank || e.mode == mode.Prolog || e.mode == mode.Config || e.mode == mode.FSTAB || e.mode == mode.Nix || e.mode == mode.Markdown || e.mode == mode.Assembly {
 			var firstLine []byte
 			byteLines := bytes.SplitN(fnord.data, []byte{'\n'}, 2)
 			if len(byteLines) > 0 {
@@ -170,31 +178,55 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 			}
 		}
 
-		// Specifically enable syntax highlighting if the opened file is a configuration file or a log file
+		// Specifically enable syntax highlighting if the opened file is a configuration file or log file
 		if e.mode == mode.Config || e.mode == mode.Log {
 			e.syntaxHighlight = true
 		}
 
+	} else if e.filename == "" { // no filename, and no data on stdin
+
+		return e, "", false, errFileNotFound
+
 	} else if fileInfo, err := os.Stat(e.filename); err == nil { // no issue
 
 		// Check if this is a directory
 		if fileInfo.IsDir() {
-			e.dirMode = true
-			// TODO: Support opening directories and giving a GitHub-like overview of projects and the git status
-			// TODO: Consider supporting file rename, finding programming symbols or git push
-			return nil, "", false, errors.New("can not open directories")
+			// Check if there is only one file in that directory
+			matches, err := filepath.Glob(strings.TrimSuffix(e.filename, "/") + "/" + "*")
+			if err == nil && len(matches) == 1 {
+				fnord.filename = matches[0]
+				e.filename = matches[0]
+			} else {
+				e.dirMode = true
+				startdirs := []string{e.filename, env.HomeDir(), "/tmp"}
+				const title = "·-––—==[ Orbiton File Browser ]==—––-·"
+				megaFileState := megafile.New(c, tty, startdirs, title, editorExecutable+" -y")
+
+				megaFileState.WrittenTextColor = e.Foreground
+				megaFileState.Background = e.Background
+				megaFileState.TitleColor = e.HeaderTextColor
+				megaFileState.PromptColor = e.LinkColor
+				megaFileState.AngleColor = e.JumpToLetterColor
+				megaFileState.EdgeBackground = e.Background            // TODO using e.BoxBackground needs some more work in megafile
+				megaFileState.HighlightBackground = vt.BackgroundWhite // TODO add to the theme struct
+
+				if _, err := megaFileState.Run(); err != nil && err != megafile.ErrExit {
+					return e, "", false, fmt.Errorf("could not browse %s: %v", e.filename, err)
+				}
+				os.Exit(0)
+			}
 		}
 
 		warningMessage, err = e.Load(c, tty, fnord)
 		if err != nil {
-			return nil, "", false, err
+			return e, "", false, err
 		}
 
 		if !e.Empty() {
 			// Detect the file mode if the current editor mode is blank (or Prolog, since it could be Perl)
 			// Markdown is set by default for some files.
-			// This corresponds to the check furthe up, and both needs to be updated in sync.
-			if e.mode == mode.Blank || e.mode == mode.Prolog || e.mode == mode.Config || (e.mode == mode.Markdown && ext != ".md") {
+			// This corresponds to the check further up, and both needs to be updated in sync.
+			if e.mode == mode.Blank || e.mode == mode.Prolog || e.mode == mode.Config || e.mode == mode.FSTAB || e.mode == mode.Nix || (e.mode == mode.Markdown && ext != ".md") {
 				firstLine := e.Line(0)
 				// The first 100 bytes are enough when trying to detect the contents
 				if len(firstLine) > 100 {
@@ -243,7 +275,7 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 					}
 				}
 				if !wantColors {
-					e.Foreground = vt100.LightRed
+					e.Foreground = vt.LightRed
 					// disable syntax highlighting, to make it clear that the text is red
 					e.syntaxHighlight = false
 				}
@@ -252,7 +284,7 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 		}
 	} else {
 		if ok, err := e.PrepareEmptySaveAndRemove(c, tty); err != nil {
-			return nil, "", false, err
+			return e, "", false, err
 		} else if ok {
 			createdNewFile = true
 		}
@@ -282,7 +314,7 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 
 	// If we're editing a git commit message, add a newline and enable word-wrap at 72
 	if e.mode == mode.Git {
-		e.Git = vt100.LightGreen
+		e.Git = vt.LightGreen
 		if filepath.Base(e.filename) == "MERGE_MSG" {
 			e.InsertLineBelow()
 		} else if e.EmptyLine() {
@@ -307,7 +339,7 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 	// Use a light theme if XTERM_VERSION (and not running with "og") or
 	// TERMINAL_EMULATOR is set to "JetBrains-JediTerm",
 	// because $COLORFGBG is "15;0" even though the background is white.
-	if !e.readOnly && (!specificLetter || editTheme) {
+	if !e.readOnly && (!specificLetter || editTheme || nanoMode) {
 		assumeLightBackground := env.Bool("O_LIGHT")
 		theme := env.StrAlt("O_THEME", "THEME")
 		if envNoColor {
@@ -330,6 +362,8 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 			e.setBlueEditTheme(assumeLightBackground)
 		case "pinetree":
 			e.SetTheme(NewPinetreeTheme(), assumeLightBackground)
+		case "zulu":
+			e.SetTheme(NewZuluTheme(), assumeLightBackground)
 		case "graymono":
 			envNoColor = false
 			e.setGrayTheme()
@@ -359,12 +393,12 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 				// NetBSD, FreeBSD, OpenBSD or Dragonfly
 				e.SetTheme(NewRedBlackTheme())
 				DisableQuickHelpScreen(nil)
-				e.clearOnQuit = true
+				clearOnQuit.Store(true)
 			} else if shell := env.Str("SHELL"); shell != "/usr/local/bin/fish" && (shell == "/bin/csh" || shell == "/bin/ksh" || strings.HasPrefix(shell, "/usr/local/bin")) && !inVTEGUI && filepath.Base(os.Args[0]) != "default" {
 				// This is likely to be FreeBSD or OpenBSD (and the executable/link name is not "default")
 				e.SetTheme(NewRedBlackTheme())
 				DisableQuickHelpScreen(nil)
-				e.clearOnQuit = true
+				clearOnQuit.Store(true)
 			} else if colorString := env.Str("COLORFGBG"); strings.Contains(colorString, ";") {
 				fields := strings.Split(colorString, ";")
 				backgroundColor := fields[len(fields)-1]
@@ -382,7 +416,7 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 				// r, g, b is the background color from the current terminal emulator, if available
 				// Checke if the combined value of r, g and b (0..1) is larger than 2
 				// (a bit arbitrary, but should work for most cases)
-				if r, g, b, err := vt100.GetBackgroundColor(tty); err == nil && r+g+b > 2 { // success and the background is not dark
+				if r, g, b, err := vt.GetBackgroundColor(tty); err == nil && r+g+b > 2 { // success and the background is not dark
 					b := true
 					initialLightBackground = &b
 					if editTheme {
@@ -454,7 +488,7 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 	}
 
 	// Redraw the TUI, if needed
-	if e.redraw.Load() {
+	if e.redraw.Load() && c != nil {
 		e.Center(c)
 		e.HideCursorDrawLines(c, true, false, false)
 		e.redraw.Store(false)
@@ -476,7 +510,13 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 		if fnord.stdin {
 			statusMessage += "Read from stdin"
 		} else {
-			statusMessage += "Loaded " + files.Relative(e.filename)
+			relFilename := files.Relative(e.filename)
+			absFilename, err := filepath.Abs(e.filename)
+			if err == nil && len(absFilename) < len(relFilename) {
+				statusMessage += "Loaded " + absFilename
+			} else {
+				statusMessage += "Loaded " + relFilename
+			}
 		}
 		if e.binaryFile {
 			statusMessage += " (binary)"
@@ -517,7 +557,7 @@ func NewEditor(tty *vt100.TTY, c *vt100.Canvas, fnord FilenameOrData, lineNumber
 // * a syntax highlighting scheme
 // * a file mode
 // * if directories should be created when saving a file if they are missing
-func NewCustomEditor(indentation mode.TabsSpaces, scrollSpeed int, m mode.Mode, theme Theme, syntaxHighlight, rainbowParenthesis, monitorAndReadOnly, createDirectoriesIfMissing, displayQuickHelp bool) *Editor {
+func NewCustomEditor(indentation mode.TabsSpaces, scrollSpeed int, m mode.Mode, theme Theme, syntaxHighlight, rainbowParenthesis, monitorAndReadOnly, createDirectoriesIfMissing, displayQuickHelp, noDisplayQuickHelp bool) *Editor {
 	e := &Editor{}
 	e.SetTheme(theme)
 	e.lines = make(map[int][]rune)
@@ -527,6 +567,7 @@ func NewCustomEditor(indentation mode.TabsSpaces, scrollSpeed int, m mode.Mode,
 	e.monitorAndReadOnly = monitorAndReadOnly
 	e.createDirectoriesIfMissing = createDirectoriesIfMissing
 	e.displayQuickHelp = displayQuickHelp
+	e.noDisplayQuickHelp = noDisplayQuickHelp
 	p := NewPosition(scrollSpeed)
 	e.pos = *p
 	// If the file is not to be highlighted, set word wrap to 79 (0 to disable)
@@ -554,14 +595,14 @@ func NewCustomEditor(indentation mode.TabsSpaces, scrollSpeed int, m mode.Mode,
 // then set the word wrap limit at the given column width.
 func NewSimpleEditor(wordWrapLimit int) *Editor {
 	t := NewDefaultTheme()
-	e := NewCustomEditor(mode.DefaultTabsSpaces, 1, mode.Blank, t, false, false, false, false, false)
+	e := NewCustomEditor(mode.DefaultTabsSpaces, 1, mode.Blank, t, false, false, false, false, false, false)
 	e.wrapWidth = wordWrapLimit
 	e.wrapWhenTyping = true
 	return e
 }
 
 // PrepareEmptySaveAndRemove prepares an empty document, saves a file and then removes it, just to check
-func (e *Editor) PrepareEmptySaveAndRemove(c *vt100.Canvas, tty *vt100.TTY) (bool, error) {
+func (e *Editor) PrepareEmptySaveAndRemove(c *vt.Canvas, tty *vt.TTY) (bool, error) {
 	// Prepare an empty file
 	if newMode, err := e.PrepareEmpty(); err != nil {
 		return false, err
