@@ -11,95 +11,122 @@ import (
 
 	"github.com/xyproto/env/v2"
 	"github.com/xyproto/files"
-	"github.com/xyproto/syntax"
-	"github.com/xyproto/textoutput"
-	"github.com/xyproto/vt100"
+	"github.com/xyproto/mode"
+	"github.com/xyproto/vt"
 )
 
-func quitError(tty *vt100.TTY, err error) {
+func quitError(tty *vt.TTY, err error) {
 	quitMut.Lock()
 	defer quitMut.Unlock()
 
+	stopBackgroundProcesses()
+
 	if tty != nil {
 		tty.Close()
 	}
-	vt100.Reset()
-	vt100.Clear()
-	vt100.Close()
-	textoutput.NewTextOutput(true, true).Err(err.Error())
-	vt100.ShowCursor(true)
-	vt100.SetXY(uint(0), uint(1))
+
+	vt.Reset()
+	vt.SetNoColor()
+	vt.Clear()
+	vt.Close()
+	vt.New().Err(err.Error())
+	vt.ShowCursor(true)
+	vt.SetXY(uint(0), uint(1))
 	os.Exit(1)
 }
 
-func quitMessage(tty *vt100.TTY, msg string) {
+func quitMessage(tty *vt.TTY, msg string) {
 	quitMut.Lock()
 	defer quitMut.Unlock()
+
+	stopBackgroundProcesses()
+
 	if tty != nil {
 		tty.Close()
 	}
-	vt100.Reset()
-	vt100.Clear()
-	vt100.Close()
+
+	vt.Reset()
+	vt.SetNoColor()
+	vt.Clear()
+	vt.Close()
 	fmt.Fprintln(os.Stderr, msg)
 	newLineCount := strings.Count(msg, "\n")
-	vt100.ShowCursor(true)
-	vt100.SetXY(uint(0), uint(newLineCount+1))
+	vt.ShowCursor(true)
+	vt.SetXY(uint(0), uint(newLineCount+1))
 	os.Exit(1)
 }
 
-func quitMessageWithStack(tty *vt100.TTY, msg string) {
+func quitMessageWithStack(tty *vt.TTY, msg string) {
 	quitMut.Lock()
 	defer quitMut.Unlock()
 
+	stopBackgroundProcesses()
+
 	if tty != nil {
 		tty.Close()
 	}
-	vt100.Reset()
-	vt100.Clear()
-	vt100.Close()
+
+	vt.Reset()
+	vt.SetNoColor()
+	vt.Clear()
+	vt.Close()
 	fmt.Fprintln(os.Stderr, msg)
 	newLineCount := strings.Count(msg, "\n")
-	vt100.ShowCursor(true)
-	vt100.SetXY(uint(0), uint(newLineCount+1))
+	vt.ShowCursor(true)
+	vt.SetXY(uint(0), uint(newLineCount+1))
 	debug.PrintStack()
 	os.Exit(1)
 }
 
-func quitExecShellCommand(tty *vt100.TTY, workDir string, shellCommand string) {
+func quitExecShellCommand(tty *vt.TTY, workDir string, shellCommand string) {
 	quitMut.Lock()
 	defer quitMut.Unlock()
+
+	stopBackgroundProcesses()
+
 	if tty != nil {
 		tty.Close()
 	}
-	vt100.Reset()
-	vt100.Clear()
-	vt100.Close()
-	vt100.ShowCursor(true)
-	vt100.SetXY(uint(0), uint(1))
+
+	vt.Reset()
+	vt.SetNoColor()
+	vt.Clear()
+	vt.Close()
+	vt.ShowCursor(true)
+	vt.SetXY(uint(0), uint(1))
 	const shellExecutable = "/bin/sh"
 	_ = os.Chdir(workDir)
 	syscall.Exec(shellExecutable, []string{shellExecutable, "-c", shellCommand}, env.Environ())
 }
 
-// quitCat tries to list the given source code file using syntax.CatBytes, and then exits
+// CatBytes detects the source code mode and outputs syntax highlighted text to the given TextOutput.
+func CatBytes(sourceCodeData []byte, o *vt.TextOutput) error {
+	detectedMode := mode.SimpleDetectBytes(sourceCodeData)
+	taggedTextBytes, err := AsText(sourceCodeData, detectedMode)
+	if err == nil {
+		o.OutputTags(string(taggedTextBytes))
+	}
+	return err
+}
+
+// quitCat tries to list the given source code file using CatBytes, and then exits
 func quitCat(fnord *FilenameOrData) {
 	quitMut.Lock()
 	defer quitMut.Unlock()
 	if fnord.Empty() {
 		if sourceCodeBytes, err := os.ReadFile(fnord.filename); err == nil { // success
-			if err := syntax.CatBytes(sourceCodeBytes, tout); err == nil { // success
-				vt100.ShowCursor(true)
+			if err := CatBytes(sourceCodeBytes, tout); err == nil { // success
+				vt.ShowCursor(true)
 				os.Exit(0)
 			}
 		}
 	} else {
-		if err := syntax.CatBytes(fnord.data, tout); err == nil { // success
-			vt100.ShowCursor(true)
+		if err := CatBytes(fnord.data, tout); err == nil { // success
+			vt.ShowCursor(true)
 			os.Exit(0)
 		}
 	}
-	vt100.ShowCursor(true)
+	vt.ShowCursor(true)
 	os.Exit(1) // could not cat the file in a syntax highlighted way
 }
 
@@ -107,7 +134,11 @@ func quitCat(fnord *FilenameOrData) {
 func quitBat(filename string) error {
 	quitMut.Lock()
 	defer quitMut.Unlock()
-	batCommandLine := env.Str("ORBITON_BAT", "bat") // TODO: Document ORBITON_BAT, for configuring flags given to bat when -c, p, -b or --bat is used
+
+	stopBackgroundProcesses()
+
+	// ORBITON_BAT environment variable allows configuring the bat command and flags used when invoking "bat" via -c, -p, -b, or --bat options.
+	batCommandLine := env.Str("ORBITON_BAT", "bat")
 	batExecutable := batCommandLine
 	args := []string{batExecutable}
 	if strings.Contains(batCommandLine, " ") {
@@ -127,18 +158,21 @@ func quitBat(filename string) error {
 		return fmt.Errorf("%q is not available in the PATH", batExecutable)
 	}
 	args = append(args, filename)
-	vt100.ShowCursor(true)
+	vt.ShowCursor(true)
 	syscall.Exec(batExecutable, args, env.Environ())
 	return nil // this is never reached
 }
 
-func quitToMan(tty *vt100.TTY, workDir, nroffFilename string, w, h uint) error {
+func quitToMan(tty *vt.TTY, workDir, nroffFilename string, w, h uint) error {
 	quitMut.Lock()
 	defer quitMut.Unlock()
 
-	vt100.Close()
-	vt100.Clear()
-	vt100.Reset()
+	stopBackgroundProcesses()
+
+	vt.Close()
+	vt.SetNoColor()
+	vt.Clear()
+	vt.Reset()
 	if tty != nil {
 		tty.Close()
 	}
@@ -147,12 +181,12 @@ func quitToMan(tty *vt100.TTY, workDir, nroffFilename string, w, h uint) error {
 		return err
 	}
 
-	oExecutable, err := filepath.Abs(os.Args[0])
-	if err != nil {
-		return err
+	editorExecutable := files.WhichCached(env.Str("EDITOR"))
+	if editorExecutable == "" {
+		return fmt.Errorf("could not find %s in PATH", env.Str("EDITOR"))
 	}
 
-	manExecutable := files.Which("man")
+	manExecutable := files.WhichCached("man")
 	args := []string{manExecutable}
 
 	if isLinux {
@@ -166,7 +200,7 @@ func quitToMan(tty *vt100.TTY, workDir, nroffFilename string, w, h uint) error {
 	}
 
 	env.Set("NROFF_FILENAME", nroffFilename)
-	env.Set("MANPAGER", oExecutable)
+	env.Set("MANPAGER", editorExecutable)
 
 	env.Set("COLUMNS", strconv.Itoa(int(w)))
 	env.Set("LINES", strconv.Itoa(int(h)))
@@ -175,13 +209,17 @@ func quitToMan(tty *vt100.TTY, workDir, nroffFilename string, w, h uint) error {
 	return nil
 }
 
-func quitToNroff(tty *vt100.TTY, backupDirectory string, w, h uint) error {
+func quitToNroff(tty *vt.TTY, backupDirectory string, w, h uint) error {
 	quitMut.Lock()
 	defer quitMut.Unlock()
 
-	vt100.Close()
-	vt100.Clear()
-	vt100.Reset()
+	stopBackgroundProcesses()
+
+	vt.Close()
+	vt.SetNoColor()
+	vt.Clear()
+	vt.Reset()
+
 	if tty != nil {
 		tty.Close()
 	}
@@ -208,7 +246,7 @@ func quitToNroff(tty *vt100.TTY, backupDirectory string, w, h uint) error {
 
 	env.Unset("NROFF_FILENAME")
 	env.Unset("MANPAGER")
-	env.Set("ORBITON_SPACE")
+	env.Set("ORBITON_SPACE") // sets ORBITON_SPACE to "1"
 
 	env.Set("COLUMNS", strconv.Itoa(int(w)))
 	env.Set("LINES", strconv.Itoa(int(h)))
