@@ -1,69 +1,18 @@
 package main
 
 import (
+	"regexp"
 	"strings"
+	"sync"
 	"unicode"
 	"unicode/utf8"
 )
 
-// hasAnyPrefixWord checks if the given line is prefixed with any one of the given words
-func hasAnyPrefixWord(line string, wordList []string) bool {
-	for _, word := range wordList {
-		if strings.HasPrefix(line, word+" ") {
-			return true
-		}
-	}
-	return false
-}
-
-// hasAnyPrefix checks if the given line is prefixed with any one of the given strings
-func hasAnyPrefix(line string, stringList []string) bool {
-	for _, s := range stringList {
-		if strings.HasPrefix(line, s) {
-			return true
-		}
-	}
-	return false
-}
-
-// hasS checks if the given string slice contains the given string
-func hasS(sl []string, s string) bool {
-	for _, e := range sl {
-		if e == s {
-			return true
-		}
-	}
-	return false
-}
-
-// firstWordContainsOneOf checks if the first word of the given string contains
-// any one of the given strings
-func firstWordContainsOneOf(s string, sl []string) bool {
-	if s == "" {
-		return false
-	}
-	fields := strings.Fields(s)
-	if len(fields) == 0 {
-		return false
-	}
-	firstWord := fields[0]
-	for _, e := range sl {
-		if strings.Contains(firstWord, e) {
-			return true
-		}
-	}
-	return false
-}
-
-// hasSuffix checks if the given string end with one of the given suffixes
-func hasSuffix(s string, suffixes []string) bool {
-	for _, suffix := range suffixes {
-		if strings.HasSuffix(s, suffix) {
-			return true
-		}
-	}
-	return false
-}
+// ansiRegex matches ANSI escape sequences
+var (
+	ansiRegex     *regexp.Regexp
+	ansiRegexOnce sync.Once
+)
 
 // hasKey checks if the given string map contains the given key
 func hasKey(m map[string]string, key string) bool {
@@ -71,32 +20,6 @@ func hasKey(m map[string]string, key string) bool {
 	return found
 }
 
-// filterS returns all strings that makes the function f return true
-func filterS(sl []string, f func(string) bool) []string {
-	var results []string
-	for _, e := range sl {
-		if f(e) {
-			results = append(results, e)
-		}
-	}
-	return results
-}
-
-// equalStringSlices checks if two given string slices are equal or not
-// returns true if they are equal
-func equalStringSlices(a, b []string) bool {
-	lena := len(a)
-	if lena != len(b) {
-		return false
-	}
-	for i := 0; i < lena; i++ {
-		if a[i] != b[i] {
-			return false
-		}
-	}
-	return true
-}
-
 // hasWords checks if a range of more than one letter is found
 func hasWords(s string) bool {
 	letterCount := 0
@@ -113,6 +36,37 @@ func hasWords(s string) bool {
 	return false
 }
 
+// hasPrefix checks if the given string starts with one of the given prefixes
+func hasPrefix(s string, prefixes []string) bool {
+	for _, prefix := range prefixes {
+		if strings.HasPrefix(s, prefix) {
+			return true
+		}
+	}
+	return false
+}
+
+// hasPrefixWithSpace checks if the given string starts with one of the given prefixes
+// plus a space after the prefix.
+func hasPrefixWithSpace(s string, prefixes []string) bool {
+	for _, prefix := range prefixes {
+		if strings.HasPrefix(s, prefix+" ") {
+			return true
+		}
+	}
+	return false
+}
+
+// containsSubstring checks if the given string contains one of the given substrings
+func containsSubstring(haystack string, substrings []string) bool {
+	for _, ss := range substrings {
+		if strings.Contains(haystack, ss) {
+			return true
+		}
+	}
+	return false
+}
+
 // allUpper checks if all letters in a string are uppercase
 func allUpper(s string) bool {
 	for _, r := range s {
@@ -136,13 +90,13 @@ func allLower(s string) bool {
 // capitalizeWords can change "john bob" to "John Bob"
 func capitalizeWords(s string) string {
 	words := strings.Fields(s)
-	var newWords []string
-	for _, word := range words {
+	newWords := make([]string, len(words))
+	for i, word := range words {
 		if len(word) > 1 {
 			capitalizedWord := strings.ToUpper(string(word[0])) + word[1:]
-			newWords = append(newWords, capitalizedWord)
+			newWords[i] = capitalizedWord
 		} else {
-			newWords = append(newWords, word)
+			newWords[i] = word
 		}
 	}
 	return strings.Join(newWords, " ")
@@ -240,7 +194,7 @@ func isAllowedFilenameChar(r rune) bool {
 
 // sanitizeFilename removes any character from the input string that is not part of a typical cross-platform filename
 func sanitizeFilename(input string) string {
-	var result []rune
+	result := make([]rune, 0, len(input))
 	for _, r := range input {
 		if isAllowedFilenameChar(r) {
 			result = append(result, r)
@@ -251,7 +205,7 @@ func sanitizeFilename(input string) string {
 
 // getLeadingWhitespace returns the leading whitespace of the given string
 func getLeadingWhitespace(line string) string {
-	var whitespace []rune
+	whitespace := make([]rune, 0, 8) // pre-allocate for the expected common case
 	for _, char := range line {
 		if unicode.IsSpace(char) {
 			whitespace = append(whitespace, char)
@@ -309,25 +263,24 @@ func trimRightSpace(str string) string {
 	return strings.TrimRightFunc(str, unicode.IsSpace)
 }
 
-// checkMultiLineString detects and updates the inCodeBlock state.
-// For languages like Nim, Mojo, Python and Starlark.
-func checkMultiLineString(trimmedLine string, inCodeBlock bool) (bool, bool) {
-	foundDocstringMarker := false
-	if trimmedLine == "\"\"\"" || trimmedLine == "'''" { // only 3 letters
-		inCodeBlock = !inCodeBlock
-		foundDocstringMarker = true
-	} else if strings.HasPrefix(trimmedLine, "\"\"\"") && strings.HasSuffix(trimmedLine, "\"\"\"") { // this could be 6 lte
-		inCodeBlock = false
-		foundDocstringMarker = true
-	} else if strings.HasPrefix(trimmedLine, "'''") && strings.HasSuffix(trimmedLine, "'''") { // this could be 6 lettersre
-		inCodeBlock = false
-		foundDocstringMarker = true
-	} else if strings.HasPrefix(trimmedLine, "\"\"\"") || strings.HasPrefix(trimmedLine, "'''") { // this is more than 3 ts
-		inCodeBlock = true
-		foundDocstringMarker = true
-	} else if strings.HasSuffix(trimmedLine, "\"\"\"") || strings.HasSuffix(trimmedLine, "'''") { // this is more than 3 ts
-		inCodeBlock = false
-		foundDocstringMarker = true
+func stripTerminalCodes(msg string) string {
+	// Regular expression to match ANSI escape sequences
+	ansiRegexOnce.Do(func() {
+		ansiRegex = regexp.MustCompile("\x1b\\[[0-9;]*[a-zA-Z]")
+	})
+	// Replace all occurrences with an empty string
+	return ansiRegex.ReplaceAllString(msg, "")
+}
+
+// Return what's between two strings, "a" and "b", in another string
+func between(orig string, a string, b string) string {
+	if strings.Contains(orig, a) && strings.Contains(orig, b) {
+		posa := strings.Index(orig, a) + len(a)
+		posb := strings.LastIndex(orig, b)
+		if posa > posb {
+			return ""
+		}
+		return orig[posa:posb]
 	}
-	return inCodeBlock, foundDocstringMarker
+	return ""
 }
