@@ -25,8 +25,8 @@ var (
 
 func init() {
 	pflag.StringVarP(&cpuProfileFilename, "cpuprofile", "u", "", "write CPU profile to `file`")
-	pflag.StringVarP(&memProfileFilename, "memprofile", "t", "", "write memory profile to `file`")
-	pflag.StringVarP(&fgtraceFilename, "fgtrace", "g", "", "write fgtrace to `file`")
+	pflag.StringVarP(&memProfileFilename, "memprofile", "w", "", "write memory profile to `file`")
+	pflag.StringVarP(&fgtraceFilename, "fgtrace", "y", "", "write fgtrace to `file`")
 
 	// Start the pprof HTTP server as well
 	go func() {
@@ -65,13 +65,11 @@ func traceComplete() {
 		f, err := os.Create(memProfileFilename)
 		if err != nil {
 			log.Fatal("could not create memory profile: ", err)
-			logf("could not create memory profile: %v\n", err)
 		}
-		defer f.Close() // error handling omitted for example
-		runtime.GC()    // get up-to-date statistics
+		defer f.Close()
+		runtime.GC() // get up-to-date statistics
 		if err := pprof.WriteHeapProfile(f); err != nil {
 			log.Fatal("could not write to memory profile: ", err)
-			logf("could not write to memory profile: %v\n", err)
 		}
 	}
 	if cpuProfileFilename != "" {
